# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

"""
ShapeAnalysis module, see official documentation at
https://dev.opencascade.org/doc/occt-7.9.0/refman/html/package_shapeanalysis.html
"""

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _ShapeAnalysis
else:
    import _ShapeAnalysis

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ShapeAnalysis.delete_SwigPyIterator

    def value(self):
        return _ShapeAnalysis.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _ShapeAnalysis.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _ShapeAnalysis.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _ShapeAnalysis.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _ShapeAnalysis.SwigPyIterator_equal(self, x)

    def copy(self):
        return _ShapeAnalysis.SwigPyIterator_copy(self)

    def next(self):
        return _ShapeAnalysis.SwigPyIterator_next(self)

    def __next__(self):
        return _ShapeAnalysis.SwigPyIterator___next__(self)

    def previous(self):
        return _ShapeAnalysis.SwigPyIterator_previous(self)

    def advance(self, n):
        return _ShapeAnalysis.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _ShapeAnalysis.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _ShapeAnalysis.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _ShapeAnalysis.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _ShapeAnalysis.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _ShapeAnalysis.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _ShapeAnalysis.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ShapeAnalysis:
_ShapeAnalysis.SwigPyIterator_swigregister(SwigPyIterator)

def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error, method_name, class_name):
    return _ShapeAnalysis.process_exception(error, method_name, class_name)

import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

class ios_base(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    erase_event = _ShapeAnalysis.ios_base_erase_event
    imbue_event = _ShapeAnalysis.ios_base_imbue_event
    copyfmt_event = _ShapeAnalysis.ios_base_copyfmt_event

    def register_callback(self, __fn, __index):
        return _ShapeAnalysis.ios_base_register_callback(self, __fn, __index)

    def flags(self, *args):
        return _ShapeAnalysis.ios_base_flags(self, *args)

    def setf(self, *args):
        return _ShapeAnalysis.ios_base_setf(self, *args)

    def unsetf(self, __mask):
        return _ShapeAnalysis.ios_base_unsetf(self, __mask)

    def precision(self, *args):
        return _ShapeAnalysis.ios_base_precision(self, *args)

    def width(self, *args):
        return _ShapeAnalysis.ios_base_width(self, *args)

    @staticmethod
    def sync_with_stdio(__sync=True):
        return _ShapeAnalysis.ios_base_sync_with_stdio(__sync)

    def imbue(self, __loc):
        return _ShapeAnalysis.ios_base_imbue(self, __loc)

    def getloc(self):
        return _ShapeAnalysis.ios_base_getloc(self)

    @staticmethod
    def xalloc():
        return _ShapeAnalysis.ios_base_xalloc()

    def iword(self, __ix):
        return _ShapeAnalysis.ios_base_iword(self, __ix)

    def pword(self, __ix):
        return _ShapeAnalysis.ios_base_pword(self, __ix)
    __swig_destroy__ = _ShapeAnalysis.delete_ios_base

# Register ios_base in _ShapeAnalysis:
_ShapeAnalysis.ios_base_swigregister(ios_base)
cvar = _ShapeAnalysis.cvar
ios_base.boolalpha = _ShapeAnalysis.cvar.ios_base_boolalpha
ios_base.dec = _ShapeAnalysis.cvar.ios_base_dec
ios_base.fixed = _ShapeAnalysis.cvar.ios_base_fixed
ios_base.hex = _ShapeAnalysis.cvar.ios_base_hex
ios_base.internal = _ShapeAnalysis.cvar.ios_base_internal
ios_base.left = _ShapeAnalysis.cvar.ios_base_left
ios_base.oct = _ShapeAnalysis.cvar.ios_base_oct
ios_base.right = _ShapeAnalysis.cvar.ios_base_right
ios_base.scientific = _ShapeAnalysis.cvar.ios_base_scientific
ios_base.showbase = _ShapeAnalysis.cvar.ios_base_showbase
ios_base.showpoint = _ShapeAnalysis.cvar.ios_base_showpoint
ios_base.showpos = _ShapeAnalysis.cvar.ios_base_showpos
ios_base.skipws = _ShapeAnalysis.cvar.ios_base_skipws
ios_base.unitbuf = _ShapeAnalysis.cvar.ios_base_unitbuf
ios_base.uppercase = _ShapeAnalysis.cvar.ios_base_uppercase
ios_base.adjustfield = _ShapeAnalysis.cvar.ios_base_adjustfield
ios_base.basefield = _ShapeAnalysis.cvar.ios_base_basefield
ios_base.floatfield = _ShapeAnalysis.cvar.ios_base_floatfield
ios_base.badbit = _ShapeAnalysis.cvar.ios_base_badbit
ios_base.eofbit = _ShapeAnalysis.cvar.ios_base_eofbit
ios_base.failbit = _ShapeAnalysis.cvar.ios_base_failbit
ios_base.goodbit = _ShapeAnalysis.cvar.ios_base_goodbit
ios_base.app = _ShapeAnalysis.cvar.ios_base_app
ios_base.ate = _ShapeAnalysis.cvar.ios_base_ate
ios_base.binary = _ShapeAnalysis.cvar.ios_base_binary
ios_base.ios_base_in = _ShapeAnalysis.cvar.ios_base_ios_base_in
ios_base.out = _ShapeAnalysis.cvar.ios_base_out
ios_base.trunc = _ShapeAnalysis.cvar.ios_base_trunc
ios_base.beg = _ShapeAnalysis.cvar.ios_base_beg
ios_base.cur = _ShapeAnalysis.cvar.ios_base_cur
ios_base.end = _ShapeAnalysis.cvar.ios_base_end

class ios(ios_base):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def rdstate(self):
        return _ShapeAnalysis.ios_rdstate(self)

    def clear(self, *args):
        return _ShapeAnalysis.ios_clear(self, *args)

    def setstate(self, __state):
        return _ShapeAnalysis.ios_setstate(self, __state)

    def good(self):
        return _ShapeAnalysis.ios_good(self)

    def eof(self):
        return _ShapeAnalysis.ios_eof(self)

    def fail(self):
        return _ShapeAnalysis.ios_fail(self)

    def bad(self):
        return _ShapeAnalysis.ios_bad(self)

    def exceptions(self, *args):
        return _ShapeAnalysis.ios_exceptions(self, *args)

    def __init__(self, __sb):
        _ShapeAnalysis.ios_swiginit(self, _ShapeAnalysis.new_ios(__sb))
    __swig_destroy__ = _ShapeAnalysis.delete_ios

    def tie(self, *args):
        return _ShapeAnalysis.ios_tie(self, *args)

    def rdbuf(self, *args):
        return _ShapeAnalysis.ios_rdbuf(self, *args)

    def copyfmt(self, __rhs):
        return _ShapeAnalysis.ios_copyfmt(self, __rhs)

    def fill(self, *args):
        return _ShapeAnalysis.ios_fill(self, *args)

    def imbue(self, __loc):
        return _ShapeAnalysis.ios_imbue(self, __loc)

    def narrow(self, __c, __dfault):
        return _ShapeAnalysis.ios_narrow(self, __c, __dfault)

    def widen(self, __c):
        return _ShapeAnalysis.ios_widen(self, __c)

# Register ios in _ShapeAnalysis:
_ShapeAnalysis.ios_swigregister(ios)
class ostream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _ShapeAnalysis.ostream_swiginit(self, _ShapeAnalysis.new_ostream(__sb))
    __swig_destroy__ = _ShapeAnalysis.delete_ostream

    def __lshift__(self, *args):
        return _ShapeAnalysis.ostream___lshift__(self, *args)

    def put(self, __c):
        return _ShapeAnalysis.ostream_put(self, __c)

    def write(self, __s, __n):
        return _ShapeAnalysis.ostream_write(self, __s, __n)

    def flush(self):
        return _ShapeAnalysis.ostream_flush(self)

    def tellp(self):
        return _ShapeAnalysis.ostream_tellp(self)

    def seekp(self, *args):
        return _ShapeAnalysis.ostream_seekp(self, *args)

# Register ostream in _ShapeAnalysis:
_ShapeAnalysis.ostream_swigregister(ostream)
class istream(ios):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _ShapeAnalysis.istream_swiginit(self, _ShapeAnalysis.new_istream(__sb))
    __swig_destroy__ = _ShapeAnalysis.delete_istream

    def __rshift__(self, *args):
        return _ShapeAnalysis.istream___rshift__(self, *args)

    def gcount(self):
        return _ShapeAnalysis.istream_gcount(self)

    def get(self, *args):
        return _ShapeAnalysis.istream_get(self, *args)

    def getline(self, *args):
        return _ShapeAnalysis.istream_getline(self, *args)

    def ignore(self, *args):
        return _ShapeAnalysis.istream_ignore(self, *args)

    def peek(self):
        return _ShapeAnalysis.istream_peek(self)

    def read(self, __s, __n):
        return _ShapeAnalysis.istream_read(self, __s, __n)

    def readsome(self, __s, __n):
        return _ShapeAnalysis.istream_readsome(self, __s, __n)

    def putback(self, __c):
        return _ShapeAnalysis.istream_putback(self, __c)

    def unget(self):
        return _ShapeAnalysis.istream_unget(self)

    def sync(self):
        return _ShapeAnalysis.istream_sync(self)

    def tellg(self):
        return _ShapeAnalysis.istream_tellg(self)

    def seekg(self, *args):
        return _ShapeAnalysis.istream_seekg(self, *args)

# Register istream in _ShapeAnalysis:
_ShapeAnalysis.istream_swigregister(istream)
class iostream(istream, ostream):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, __sb):
        _ShapeAnalysis.iostream_swiginit(self, _ShapeAnalysis.new_iostream(__sb))
    __swig_destroy__ = _ShapeAnalysis.delete_iostream

# Register iostream in _ShapeAnalysis:
_ShapeAnalysis.iostream_swigregister(iostream)
cin = cvar.cin
cout = cvar.cout
cerr = cvar.cerr
clog = cvar.clog

endl_cb_ptr = _ShapeAnalysis.endl_cb_ptr
endl = _ShapeAnalysis.endl
ends_cb_ptr = _ShapeAnalysis.ends_cb_ptr
ends = _ShapeAnalysis.ends
flush_cb_ptr = _ShapeAnalysis.flush_cb_ptr
flush = _ShapeAnalysis.flush
import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.ShapeExtend
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TColGeom
import OCC.Core.TopTools
import OCC.Core.Geom2d
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.IntRes2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_ShapeAnalysis_FreeBoundData_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_FreeBoundData_Create()

def Handle_ShapeAnalysis_FreeBoundData_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_FreeBoundData_DownCast(t)

def Handle_ShapeAnalysis_FreeBoundData_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_FreeBoundData_IsNull(t)

def Handle_ShapeAnalysis_Surface_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_Surface_Create()

def Handle_ShapeAnalysis_Surface_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_Surface_DownCast(t)

def Handle_ShapeAnalysis_Surface_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_Surface_IsNull(t)

def Handle_ShapeAnalysis_TransferParameters_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParameters_Create()

def Handle_ShapeAnalysis_TransferParameters_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParameters_DownCast(t)

def Handle_ShapeAnalysis_TransferParameters_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParameters_IsNull(t)

def Handle_ShapeAnalysis_Wire_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_Wire_Create()

def Handle_ShapeAnalysis_Wire_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_Wire_DownCast(t)

def Handle_ShapeAnalysis_Wire_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_Wire_IsNull(t)

def Handle_ShapeAnalysis_TransferParametersProj_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParametersProj_Create()

def Handle_ShapeAnalysis_TransferParametersProj_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParametersProj_DownCast(t)

def Handle_ShapeAnalysis_TransferParametersProj_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_TransferParametersProj_IsNull(t)

def Handle_ShapeAnalysis_HSequenceOfFreeBounds_Create():
    return _ShapeAnalysis.Handle_ShapeAnalysis_HSequenceOfFreeBounds_Create()

def Handle_ShapeAnalysis_HSequenceOfFreeBounds_DownCast(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_HSequenceOfFreeBounds_DownCast(t)

def Handle_ShapeAnalysis_HSequenceOfFreeBounds_IsNull(t):
    return _ShapeAnalysis.Handle_ShapeAnalysis_HSequenceOfFreeBounds_IsNull(t)
class ShapeAnalysis_BoxBndTree(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ShapeAnalysis.ShapeAnalysis_BoxBndTree_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_BoxBndTree(*args))

    def Add(self, theObj, theBnd):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_Add(self, theObj, theBnd)

    def Select(self, theSelector):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_Select(self, theSelector)

    def Clear(self, aNewAlloc=0):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_Clear(self, aNewAlloc)

    def IsEmpty(self):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_IsEmpty(self)

    def Root(self):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_Root(self)
    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_BoxBndTree

    def Allocator(self):
        return _ShapeAnalysis.ShapeAnalysis_BoxBndTree_Allocator(self)

# Register ShapeAnalysis_BoxBndTree in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_BoxBndTree_swigregister(ShapeAnalysis_BoxBndTree)
class ShapeAnalysis_DataMapOfShapeListOfReal(OCC.Core.NCollection.NCollection_BaseMap):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_begin(self)

    def end(self):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_end(self)

    def cbegin(self):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_cbegin(self)

    def cend(self):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_cend(self)

    def __init__(self, *args):
        _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_DataMapOfShapeListOfReal(*args))

    def Exchange(self, theOther):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Exchange(self, theOther)

    def Assign(self, theOther):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Assign(self, theOther)

    def Set(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Set(self, *args)

    def ReSize(self, N):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_ReSize(self, N)

    def Bind(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Bind(self, *args)

    def Bound(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Bound(self, *args)

    def IsBound(self, theKey):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_IsBound(self, theKey)

    def UnBind(self, theKey):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_UnBind(self, theKey)

    def Seek(self, theKey):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Seek(self, theKey)

    def Find(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Find(self, *args)

    def ChangeSeek(self, theKey):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_ChangeFind(self, theKey)

    def __call__(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal___call__(self, *args)

    def Clear(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Clear(self, *args)
    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_DataMapOfShapeListOfReal

    def Size(self):
        return _ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_Size(self)

# Register ShapeAnalysis_DataMapOfShapeListOfReal in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_DataMapOfShapeListOfReal_swigregister(ShapeAnalysis_DataMapOfShapeListOfReal)
class ShapeAnalysis_SequenceOfFreeBounds(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_begin(self)

    def end(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_end(self)

    def cbegin(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_cbegin(self)

    def cend(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_cend(self)

    def __init__(self, *args):
        _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_SequenceOfFreeBounds(*args))

    def Size(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Size(self)

    def Length(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Length(self)

    def Lower(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Lower(self)

    def Upper(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Upper(self)

    def IsEmpty(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_IsEmpty(self)

    def Reverse(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Reverse(self)

    def Exchange(self, I, J):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode, theAl):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_delNode(theNode, theAl)

    def Clear(self, theAllocator=0):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Clear(self, theAllocator)

    def Assign(self, theOther):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Assign(self, theOther)

    def Set(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Set(self, *args)

    def Remove(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Remove(self, *args)

    def Append(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Append(self, *args)

    def Prepend(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Prepend(self, *args)

    def InsertBefore(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_InsertBefore(self, *args)

    def InsertAfter(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_InsertAfter(self, *args)

    def Split(self, theIndex, theSeq):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Split(self, theIndex, theSeq)

    def First(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_First(self)

    def ChangeFirst(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_ChangeFirst(self)

    def Last(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Last(self)

    def ChangeLast(self):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_ChangeLast(self)

    def Value(self, theIndex):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_Value(self, theIndex)

    def ChangeValue(self, theIndex):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_ChangeValue(self, theIndex)

    def __call__(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds___call__(self, *args)

    def SetValue(self, theIndex, theItem):
        return _ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_SequenceOfFreeBounds

    def __len__(self):
        return self.Size()


# Register ShapeAnalysis_SequenceOfFreeBounds in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_SequenceOfFreeBounds_swigregister(ShapeAnalysis_SequenceOfFreeBounds)
class shapeanalysis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AdjustByPeriod(*args):
        r"""

        Parameters
        ----------
        Val: float
        ToVal: float
        Period: float

        Return
        -------
        float

        Description
        -----------
        Returns a shift required to move point <Val> to the range [ToVal-Period/2,ToVal+Period/2]. This shift will be the divisible by Period. Intended for adjusting parameters on periodic surfaces.

        """
        return _ShapeAnalysis.shapeanalysis_AdjustByPeriod(*args)

    @staticmethod
    def AdjustToPeriod(*args):
        r"""

        Parameters
        ----------
        Val: float
        ValMin: float
        ValMax: float

        Return
        -------
        float

        Description
        -----------
        Returns a shift required to move point <Val> to the range [ValMin,ValMax]. This shift will be the divisible by Period with Period = ValMax - ValMin. Intended for adjusting parameters on periodic surfaces.

        """
        return _ShapeAnalysis.shapeanalysis_AdjustToPeriod(*args)

    @staticmethod
    def ContourArea(*args):
        r"""

        Parameters
        ----------
        theWire: TopoDS_Wire

        Return
        -------
        float

        Description
        -----------
        Returns a total area of 3d wire.

        """
        return _ShapeAnalysis.shapeanalysis_ContourArea(*args)

    @staticmethod
    def FindBounds(*args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        V1: TopoDS_Vertex
        V2: TopoDS_Vertex

        Return
        -------
        None

        Description
        -----------
        Finds the start and end vertices of the shape Shape can be of the following type: vertex: V1 and V2 are the same and equal to <shape>, edge: V1 is start and V2 is end vertex (see ShapeAnalysis_Edge methods FirstVertex and LastVertex), wire: V1 is start vertex of the first edge, V2 is end vertex of the last edge (also see ShapeAnalysis_Edge). If wire contains no edges V1 and V2 are nullified If none of the above V1 and V2 are nullified.

        """
        return _ShapeAnalysis.shapeanalysis_FindBounds(*args)

    @staticmethod
    def GetFaceUVBounds(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        Umin: float
        Umax: float
        Vmin: float
        Vmax: float

        Description
        -----------
        Computes exact UV bounds of all wires on the face.

        """
        return _ShapeAnalysis.shapeanalysis_GetFaceUVBounds(*args)

    @staticmethod
    def IsOuterBound(*args):
        r"""

        Parameters
        ----------
        face: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        Returns True if <F> has outer bound.

        """
        return _ShapeAnalysis.shapeanalysis_IsOuterBound(*args)

    @staticmethod
    def OuterWire(*args):
        r"""

        Parameters
        ----------
        theFace: TopoDS_Face

        Return
        -------
        TopoDS_Wire

        Description
        -----------
        Returns positively oriented wire in the face. If there is no such wire - returns the last wire of the face.

        """
        return _ShapeAnalysis.shapeanalysis_OuterWire(*args)

    @staticmethod
    def TotCross2D(*args):
        r"""

        Parameters
        ----------
        sewd: ShapeExtend_WireData
        aFace: TopoDS_Face

        Return
        -------
        float

        Description
        -----------
        Returns a total area of 2d wire.

        """
        return _ShapeAnalysis.shapeanalysis_TotCross2D(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeAnalysis.shapeanalysis_swiginit(self, _ShapeAnalysis.new_shapeanalysis())
    __swig_destroy__ = _ShapeAnalysis.delete_shapeanalysis

# Register shapeanalysis in _ShapeAnalysis:
_ShapeAnalysis.shapeanalysis_swigregister(shapeanalysis)
class ShapeAnalysis_CanonicalRecognition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        constructor with shape initialisation.

        """
        _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_CanonicalRecognition(*args))

    def ClearStatus(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Returns status to be equal 0.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_ClearStatus(self, *args)

    def GetGap(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns deviation between input geometry entity and analytical entity.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_GetGap(self, *args)

    def GetShape(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        Returns input shape.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_GetShape(self, *args)

    def GetStatus(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns status of operation. Current meaning of possible values of status: -1 - algorithm is not initalazed by shape 0 - no errors 1 - error during any operation (usually - because of wrong input data) Any operation (calling any methods like IsPlane(...), ...) can be performed when current staue is equal 0. If after any operation status != 0, it is necessary to set it 0 by method ClearStatus() before calling other operation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_GetStatus(self, *args)

    def IsCircle(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theCirc: gp_Circ

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined curve can be represent by circle with tolerance theTol and sets in theCirc the result circle.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsCircle(self, *args)

    def IsCone(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theCone: gp_Cone

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined surface can be represent by conical one with tolerance theTol and sets in theCone the result conical surface.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsCone(self, *args)

    def IsCylinder(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theCyl: gp_Cylinder

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined surface can be represent by cylindrical one with tolerance theTol and sets in theCyl the result cylinrical surface.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsCylinder(self, *args)

    def IsEllipse(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theElips: gp_Elips

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined curve can be represent by ellipse with tolerance theTol and sets in theCirc the result ellipse.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsEllipse(self, *args)

    def IsLine(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theLin: gp_Lin

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined curve can be represent by line with tolerance theTol and sets in theLin the result line.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsLine(self, *args)

    def IsPlane(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        thePln: gp_Pln

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined surface can be represent by plane with tolerance theTol and sets in thePln the result plane.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsPlane(self, *args)

    def IsSphere(self, *args):
        r"""

        Parameters
        ----------
        theTol: float
        theSphere: gp_Sphere

        Return
        -------
        bool

        Description
        -----------
        Returns true if the underlined surface can be represent by spherical one with tolerance theTol and sets in theSphere the result spherical surface.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_IsSphere(self, *args)

    def SetShape(self, *args):
        r"""

        Parameters
        ----------
        theShape: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        Sets shape.

        """
        return _ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_SetShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_CanonicalRecognition

# Register ShapeAnalysis_CanonicalRecognition in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_CanonicalRecognition_swigregister(ShapeAnalysis_CanonicalRecognition)
class ShapeAnalysis_CheckSmallFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates an empty tool Checks a Shape i.e. each of its faces, records checks as diagnostics in the <infos> //! If <infos> has not been set before, no check is done //! For faces which are in a Shell, topological data are recorded to allow recovering connectivities after fixing or removing the small faces or parts of faces Enchains various checks on a face inshell: to compute more information, relevant to topology.

        """
        _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_CheckSmallFace(*args))

    def CheckPin(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        whatrow: int
        sence: int

        Description
        -----------
        Checks if a Face has a pin, which can be edited No singularity: no pin, returns 0 If there is a pin, checked topics, with returned value: - 0: nothing to do more - 1: 'smooth', i.e. not a really sharp pin -> diagnostic 'SmoothPin' - 2: stretched pin, i.e. is possible to relimit the face by another vertex, so that this vertex still gives a pin -> diagnostic 'StretchedPin' with location of vertex (Pnt).

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckPin(self, *args)

    def CheckPinEdges(self, *args):
        r"""

        Parameters
        ----------
        theFirstEdge: TopoDS_Edge
        theSecondEdge: TopoDS_Edge
        coef1: float
        coef2: float
        toler: float

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckPinEdges(self, *args)

    def CheckPinFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        mapEdges: TopTools_DataMapOfShapeShape
        toler: float (optional, default to -1.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckPinFace(self, *args)

    def CheckSingleStrip(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        tol: float (optional, default to -1.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if a Face is a single strip, i.e. brings two great edges which are confused on their whole length, possible other edges are small or null length //! Returns 0 if not a strip support, 1 strip in U, 2 strip in V Records diagnostic in info if it is a single strip.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckSingleStrip(self, *args)

    def CheckSplittingVertices(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        MapEdges: TopTools_DataMapOfShapeListOfShape
        MapParam: ShapeAnalysis_DataMapOfShapeListOfReal
        theAllVert: TopoDS_Compound

        Return
        -------
        int

        Description
        -----------
        Checks if a Face brings vertices which split it, either confused with non adjacent vertices, or confused with their projection on non adjacent edges Returns the count of found splitting vertices Each vertex then brings a diagnostic 'SplittingVertex', with data: 'Face' for the face, 'Edge' for the split edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckSplittingVertices(self, *args)

    def CheckSpotFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        tol: float (optional, default to -1.0)

        Return
        -------
        bool

        Description
        -----------
        Acts as IsSpotFace, but records in <infos> a diagnostic 'SpotFace' with the Pnt as value (data 'Location').

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckSpotFace(self, *args)

    def CheckStripEdges(self, *args):
        r"""

        Parameters
        ----------
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        tol: float

        Return
        -------
        dmax: float

        Description
        -----------
        Checks if two edges define a strip, i.e. distance maxi below tolerance, given or some of those of E1 and E2.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckStripEdges(self, *args)

    def CheckStripFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        tol: float (optional, default to -1.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if a Face is as a Strip Returns 0 if not or non determined, 1 if in U, 2 if in V By default, considers the tolerance zone of its edges A given value <tol> may be given to check a strip of max this width //! If a Face is determined as a Strip, it is delinited by two lists of edges. These lists are recorded in diagnostic Diagnostic 'StripFace' brings data 'Direction' (U or V), 'List1' , 'List2' (if they could be computed).

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckStripFace(self, *args)

    def CheckTwisted(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        paramu: float
        paramv: float

        Description
        -----------
        Checks if a Face is twisted (apart from checking Pin, i.e. it does not give information on pin, only 'it is twisted').

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_CheckTwisted(self, *args)

    def FindStripEdges(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        tol: float

        Return
        -------
        dmax: float

        Description
        -----------
        Searches for two and only two edges up tolerance Returns True if OK, false if not 2 edges If True, returns the two edges and their maximum distance.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_FindStripEdges(self, *args)

    def IsSpotFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        spot: gp_Pnt
        tol: float (optional, default to -1.0)

        Return
        -------
        spotol: float

        Description
        -----------
        Checks if a Face is as a Spot Returns 0 if not, 1 if yes, 2 if yes and all vertices are the same By default, considers the tolerance zone of its vertices A given value <tol> may be given to check a spot of this size If a Face is a Spot, its location is returned in <spot>, and <spotol> returns an equivalent tolerance, which is computed as half of max dimension of min-max box of the face.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_IsSpotFace(self, *args)

    def IsStripSupport(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        tol: float (optional, default to -1.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if a Face lies on a Surface which is a strip So the Face is a strip. But a Face may be a strip elsewhere .. //! A given value <tol> may be given to check max width By default, considers the tolerance zone of its edges Returns 0 if not a strip support, 1 strip in U, 2 strip in V.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_IsStripSupport(self, *args)

    def SetTolerance(self, *args):
        r"""

        Parameters
        ----------
        tol: float

        Return
        -------
        None

        Description
        -----------
        Sets a fixed Tolerance to check small face By default, local tolerance zone is considered Sets a fixed MaxTolerance to check small face Sets a fixed Tolerance to check small face By default, local tolerance zone is considered Unset fixed tolerance, comes back to local tolerance zones Unset fixed tolerance, comes back to local tolerance zones.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_SetTolerance(self, *args)

    def Status(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        Returns the status of last call to Perform() ShapeExtend_OK: face was OK, nothing done ShapeExtend_DONE1: some wires are fixed ShapeExtend_DONE2: orientation of wires fixed ShapeExtend_DONE3: missing seam added ShapeExtend_DONE4: small area wire removed ShapeExtend_DONE5: natural bounds added ShapeExtend_FAIL1: some fails during fixing wires ShapeExtend_FAIL2: cannot fix orientation of wires ShapeExtend_FAIL3: cannot add missing seam ShapeExtend_FAIL4: cannot remove small area wire.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_Status(self, *args)

    def StatusPin(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusPin(self, *args)

    def StatusPinEdges(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusPinEdges(self, *args)

    def StatusPinFace(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusPinFace(self, *args)

    def StatusSplitVert(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusSplitVert(self, *args)

    def StatusSpot(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusSpot(self, *args)

    def StatusStrip(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusStrip(self, *args)

    def StatusTwisted(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_StatusTwisted(self, *args)

    def Tolerance(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the tolerance to check small faces, negative value if local tolerances zones are to be considered.

        """
        return _ShapeAnalysis.ShapeAnalysis_CheckSmallFace_Tolerance(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_CheckSmallFace

# Register ShapeAnalysis_CheckSmallFace in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_CheckSmallFace_swigregister(ShapeAnalysis_CheckSmallFace)
class ShapeAnalysis_Curve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def FillBndBox(self, *args):
        r"""

        Parameters
        ----------
        C2d: Geom2d_Curve
        First: float
        Last: float
        NPoints: int
        Exact: bool
        Box: Bnd_Box2d

        Return
        -------
        None

        Description
        -----------
        Computes a boundary box on segment of curve C2d from First to Last. This is done by taking NPoints points from the curve and, if Exact is True, by searching for exact extrema. All these points are added to Box.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_FillBndBox(self, *args)

    @staticmethod
    def GetSamplePoints(*args):
        r"""

        Parameters
        ----------
        curve: Geom2d_Curve
        first: float
        last: float
        seq: TColgp_SequenceOfPnt2d

        Return
        -------
        bool

        Description
        -----------
        Returns sample points which will serve as linearisation of the2d curve in range (first, last) The distribution of sample points is consystent with what is used by BRepTopAdaptor_FClass2d.

        Parameters
        ----------
        curve: Geom_Curve
        first: float
        last: float
        seq: TColgp_SequenceOfPnt

        Return
        -------
        bool

        Description
        -----------
        Returns sample points which will serve as linearisation of the curve in range (first, last).

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_GetSamplePoints(*args)

    @staticmethod
    def IsClosed(*args):
        r"""

        Parameters
        ----------
        curve: Geom_Curve
        preci: float (optional, default to -1)

        Return
        -------
        bool

        Description
        -----------
        Tells if the Curve is closed with given precision. If <preci> < 0 then Precision::Confusion is used.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_IsClosed(*args)

    @staticmethod
    def IsPeriodic(*args):
        r"""

        Parameters
        ----------
        curve: Geom_Curve

        Return
        -------
        bool

        Description
        -----------
        This method was implemented as fix for changes in trimmed curve behaviour. For the moment trimmed curve returns false anyway. So it is necessary to adapt all Data exchange tools for this behaviour. Current implementation takes into account that curve may be offset.

        Parameters
        ----------
        curve: Geom2d_Curve

        Return
        -------
        bool

        Description
        -----------
        The same as for Curve3d.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_IsPeriodic(*args)

    @staticmethod
    def IsPlanar(*args):
        r"""

        Parameters
        ----------
        pnts: TColgp_Array1OfPnt
        Normal: gp_XYZ
        preci: float (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks if points are planar with given preci. If Normal has not zero modulus, checks with given normal.

        Parameters
        ----------
        curve: Geom_Curve
        Normal: gp_XYZ
        preci: float (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks if curve is planar with given preci. If Normal has not zero modulus, checks with given normal.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_IsPlanar(*args)

    def NextProject(self, *args):
        r"""

        Parameters
        ----------
        paramPrev: float
        C3D: Geom_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt
        cf: float
        cl: float
        AdjustToEnds: bool (optional, default to Standard_True)

        Return
        -------
        param: float

        Description
        -----------
        Projects a Point on a Curve using Newton method. <paramPrev> is taken as the first approximation of solution. If Newton algorithm fails the method Project() is used. If AdjustToEnds is True, point will be adjusted to the end of the curve if distance is less than <preci>.

        Parameters
        ----------
        paramPrev: float
        C3D: Adaptor3d_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt

        Return
        -------
        param: float

        Description
        -----------
        Projects a Point on a Curve using Newton method. <paramPrev> is taken as the first approximation of solution. If Newton algorithm fails the method Project() is used.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_NextProject(self, *args)

    def Project(self, *args):
        r"""

        Parameters
        ----------
        C3D: Geom_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt
        AdjustToEnds: bool (optional, default to Standard_True)

        Return
        -------
        param: float

        Description
        -----------
        Projects a Point on a Curve. Computes the projected point and its parameter on the curve. <preci> is used as 3d precision (hence, 0 will produce reject unless exact confusion). The number of iterations is limited. If AdjustToEnds is True, point will be adjusted to the end of the curve if distance is less than <preci> //! Returned value is the distance between the given point and computed one.

        Parameters
        ----------
        C3D: Adaptor3d_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt
        AdjustToEnds: bool (optional, default to Standard_True)

        Return
        -------
        param: float

        Description
        -----------
        Projects a Point on a Curve. Computes the projected point and its parameter on the curve. <preci> is used as 3d precision (hence, 0 will produce reject unless exact confusion). The number of iterations is limited. //! Returned value is the distance between the given point and computed one.

        Parameters
        ----------
        C3D: Geom_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt
        cf: float
        cl: float
        AdjustToEnds: bool (optional, default to Standard_True)

        Return
        -------
        param: float

        Description
        -----------
        Projects a Point on a Curve, but parameters are limited between <cf> and <cl>. The range [cf, cl] is extended with help of Adaptor3d on the basis of 3d precision <preci>. If AdjustToEnds is True, point will be adjusted to the end of the curve if distance is less than <preci>.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_Project(self, *args)

    def ProjectAct(self, *args):
        r"""

        Parameters
        ----------
        C3D: Adaptor3d_Curve
        P3D: gp_Pnt
        preci: float
        proj: gp_Pnt

        Return
        -------
        param: float

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_ProjectAct(self, *args)

    def SelectForwardSeam(self, *args):
        r"""

        Parameters
        ----------
        C1: Geom2d_Curve
        C2: Geom2d_Curve

        Return
        -------
        int

        Description
        -----------
        Defines which pcurve (C1 or C2) should be chosen for FORWARD seam edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_SelectForwardSeam(self, *args)

    def ValidateRange(self, *args):
        r"""

        Parameters
        ----------
        Crv: Geom_Curve
        prec: float

        Return
        -------
        First: float
        Last: float

        Description
        -----------
        Validate parameters First and Last for the given curve in order to make them valid for creation of edge. This includes: - limiting range [First,Last] by range of curve - adjusting range [First,Last] for periodic (or closed) curve if Last < First Returns True if parameters are OK or are successfully corrected, or False if parameters cannot be corrected. In the latter case, parameters are reset to range of curve.

        """
        return _ShapeAnalysis.ShapeAnalysis_Curve_ValidateRange(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeAnalysis.ShapeAnalysis_Curve_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Curve())
    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Curve

# Register ShapeAnalysis_Curve in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Curve_swigregister(ShapeAnalysis_Curve)
class ShapeAnalysis_Edge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor; initialises Status to OK.

        """
        _ShapeAnalysis.ShapeAnalysis_Edge_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Edge(*args))

    def BoundUV(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face
        first: gp_Pnt2d
        last: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location
        first: gp_Pnt2d
        last: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        Returns the ends of pcurve Calls method PCurve with <orient> equal to True.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_BoundUV(self, *args)

    def CheckCurve3dWithPCurve(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location

        Return
        -------
        bool

        Description
        -----------
        Checks mutual orientation of 3d curve and pcurve on the analysis of curves bounding points.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckCurve3dWithPCurve(self, *args)

    def CheckOverlapping(self, *args):
        r"""

        Parameters
        ----------
        theEdge1: TopoDS_Edge
        theEdge2: TopoDS_Edge
        theDomainDist: float (optional, default to 0.0)

        Return
        -------
        theTolOverlap: float

        Description
        -----------
        Checks the first edge is overlapped with second edge. If distance between two edges is less then theTolOverlap edges are overlapped. theDomainDis - length of part of edges on which edges are overlapped.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckOverlapping(self, *args)

    def CheckPCurveRange(self, *args):
        r"""

        Parameters
        ----------
        theFirst: float
        theLast: float
        thePC: Geom2d_Curve

        Return
        -------
        bool

        Description
        -----------
        Checks possibility for pcurve thePC to have range [theFirst, theLast] (edge range) having respect to real first, last parameters of thePC.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckPCurveRange(self, *args)

    def CheckSameParameter(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        NbControl: int (optional, default to 23)

        Return
        -------
        maxdev: float

        Description
        -----------
        Checks the edge to be SameParameter. Calculates the maximal deviation between 3d curve and each pcurve of the edge on <NbControl> equidistant points (the same algorithm as in BRepCheck; default value is 23 as in BRepCheck). This deviation is returned in <maxdev> parameter. If deviation is greater than tolerance of the edge (i.e. incorrect flag) returns False, else returns True.

        Parameters
        ----------
        theEdge: TopoDS_Edge
        theFace: TopoDS_Face
        theNbControl: int (optional, default to 23)

        Return
        -------
        theMaxdev: float

        Description
        -----------
        Checks the edge to be SameParameter. Calculates the maximal deviation between 3d curve and each pcurve of the edge on <NbControl> equidistant points (the same algorithm as in BRepCheck; default value is 23 as in BRepCheck). This deviation is returned in <maxdev> parameter. If deviation is greater than tolerance of the edge (i.e. incorrect flag) returns False, else returns True.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckSameParameter(self, *args)

    def CheckVertexTolerance(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face

        Return
        -------
        toler1: float
        toler2: float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge

        Return
        -------
        toler1: float
        toler2: float

        Description
        -----------
        Checks if it is necessary to increase tolerances of the edge vertices to comprise the ends of 3d curve and pcurve on the given face (first method) or all pcurves stored in an edge (second one) toler1 returns necessary tolerance for first vertex, toler2 returns necessary tolerance for last vertex.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckVertexTolerance(self, *args)

    def CheckVerticesWithCurve3d(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        preci: float (optional, default to -1)
        vtx: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks the start and/or end vertex of the edge for matching with 3d curve with the given precision. <vtx> = 1: start vertex only <vtx> = 2: end vertex only <vtx> = 0: both (default) If preci < 0 the vertices are considered with their own tolerances, else with the given <preci>.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckVerticesWithCurve3d(self, *args)

    def CheckVerticesWithPCurve(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face
        preci: float (optional, default to -1)
        vtx: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location
        preci: float (optional, default to -1)
        vtx: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks the start and/or end vertex of the edge for matching with pcurve with the given precision. <vtx> = 1: start vertex <vtx> = 2: end vertex <vtx> = 0: both If preci < 0 the vertices are considered with their own tolerances, else with the given <preci>.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_CheckVerticesWithPCurve(self, *args)

    def Curve3d(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        C3d: Geom_Curve
        orient: bool (optional, default to Standard_True)

        Return
        -------
        cf: float
        cl: float

        Description
        -----------
        Returns the 3d curve and bounding parameters for the edge Returns False if no 3d curve. If <orient> is True (default), takes orientation into account: if the edge is reversed, cf and cl are toggled.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_Curve3d(self, *args)

    def FirstVertex(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge

        Return
        -------
        TopoDS_Vertex

        Description
        -----------
        Returns start vertex of the edge (taking edge orientation into account).

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_FirstVertex(self, *args)

    def GetEndTangent2d(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face
        atEnd: bool
        pos: gp_Pnt2d
        tang: gp_Vec2d
        dparam: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location
        atEnd: bool
        pos: gp_Pnt2d
        tang: gp_Vec2d
        dparam: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Returns tangent of the edge pcurve at its start (if atEnd is False) or end (if True), regarding the orientation of edge. If edge is REVERSED, tangent is reversed before return. Returns True if pcurve is available and tangent is computed and is not null, else False.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_GetEndTangent2d(self, *args)

    def HasCurve3d(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        Tells if the edge has a 3d curve.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_HasCurve3d(self, *args)

    def HasPCurve(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        Tells if the Edge has a pcurve on the face.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location

        Return
        -------
        bool

        Description
        -----------
        Tells if the edge has a pcurve on the surface (with location).

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_HasPCurve(self, *args)

    def IsClosed3d(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        Gives True if the edge has a 3d curve, this curve is closed, and the edge has the same vertex at start and end.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_IsClosed3d(self, *args)

    def IsSeam(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location

        Return
        -------
        bool

        Description
        -----------
        Returns True if the edge has two pcurves on one surface.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_IsSeam(self, *args)

    def LastVertex(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge

        Return
        -------
        TopoDS_Vertex

        Description
        -----------
        Returns end vertex of the edge (taking edge orientation into account).

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_LastVertex(self, *args)

    def PCurve(self, *args):
        r"""

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face
        C2d: Geom2d_Curve
        orient: bool (optional, default to Standard_True)

        Return
        -------
        cf: float
        cl: float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        edge: TopoDS_Edge
        surface: Geom_Surface
        location: TopLoc_Location
        C2d: Geom2d_Curve
        orient: bool (optional, default to Standard_True)

        Return
        -------
        cf: float
        cl: float

        Description
        -----------
        Returns the pcurve and bounding parameters for the edge lying on the surface. Returns False if the edge has no pcurve on this surface. If <orient> is True (default), takes orientation into account: if the edge is reversed, cf and cl are toggled.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_PCurve(self, *args)

    def Status(self, *args):
        r"""

        Parameters
        ----------
        status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        Returns the status (in the form of True/False) of last Check.

        """
        return _ShapeAnalysis.ShapeAnalysis_Edge_Status(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Edge

# Register ShapeAnalysis_Edge in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Edge_swigregister(ShapeAnalysis_Edge)
class ShapeAnalysis_FreeBoundData(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        freebound: TopoDS_Wire

        Return
        -------
        None

        Description
        -----------
        Creates object with contour given in the form of TopoDS_Wire.

        """
        _ShapeAnalysis.ShapeAnalysis_FreeBoundData_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_FreeBoundData(*args))

    def AddNotch(self, *args):
        r"""

        Parameters
        ----------
        notch: TopoDS_Wire
        width: float

        Return
        -------
        None

        Description
        -----------
        Adds notch on the contour with its maximum width.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_AddNotch(self, *args)

    def Area(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns area of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Area(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clears all properties of the contour. Contour bound itself is not cleared.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Clear(self, *args)

    def FreeBound(self, *args):
        r"""
        Return
        -------
        TopoDS_Wire

        Description
        -----------
        Returns contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_FreeBound(self, *args)

    def NbNotches(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns number of notches on the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_NbNotches(self, *args)

    def Notch(self, *args):
        r"""

        Parameters
        ----------
        index: int

        Return
        -------
        TopoDS_Wire

        Description
        -----------
        Returns notch on the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Notch(self, *args)

    def NotchWidth(self, *args):
        r"""

        Parameters
        ----------
        index: int

        Return
        -------
        float

        Description
        -----------
        Returns maximum width of notch specified by its rank number on the contour.

        Parameters
        ----------
        notch: TopoDS_Wire

        Return
        -------
        float

        Description
        -----------
        Returns maximum width of notch specified as TopoDS_Wire on the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_NotchWidth(self, *args)

    def Notches(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        Returns sequence of notches on the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Notches(self, *args)

    def Perimeter(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns perimeter of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Perimeter(self, *args)

    def Ratio(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns ratio of average length to average width of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Ratio(self, *args)

    def SetArea(self, *args):
        r"""

        Parameters
        ----------
        area: float

        Return
        -------
        None

        Description
        -----------
        Sets area of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_SetArea(self, *args)

    def SetFreeBound(self, *args):
        r"""

        Parameters
        ----------
        freebound: TopoDS_Wire

        Return
        -------
        None

        Description
        -----------
        Sets contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_SetFreeBound(self, *args)

    def SetPerimeter(self, *args):
        r"""

        Parameters
        ----------
        perimeter: float

        Return
        -------
        None

        Description
        -----------
        Sets perimeter of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_SetPerimeter(self, *args)

    def SetRatio(self, *args):
        r"""

        Parameters
        ----------
        ratio: float

        Return
        -------
        None

        Description
        -----------
        Sets ratio of average length to average width of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_SetRatio(self, *args)

    def SetWidth(self, *args):
        r"""

        Parameters
        ----------
        width: float

        Return
        -------
        None

        Description
        -----------
        Sets average width of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_SetWidth(self, *args)

    def Width(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns average width of the contour.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundData_Width(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_FreeBoundData_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_FreeBoundData

# Register ShapeAnalysis_FreeBoundData in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_FreeBoundData_swigregister(ShapeAnalysis_FreeBoundData)
class ShapeAnalysis_FreeBounds(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        shape: TopoDS_Shape
        toler: float
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_True)

        Return
        -------
        None

        Description
        -----------
        Builds forecasting free bounds of the <shape>. <shape> should be a compound of faces. This constructor is to be used for forecasting free edges with help of sewing analyzer BRepAlgo_Sewing which is called with tolerance <toler>. Free edges are connected into wires only when their ends are at distance less than <toler>. If <splitclosed> is True extracts closed sub-wires out of built closed wires. If <splitopen> is True extracts closed sub-wires out of built open wires.

        Parameters
        ----------
        shape: TopoDS_Shape
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_True)
        checkinternaledges: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Builds actual free bounds of the <shape>. <shape> should be a compound of shells. This constructor is to be used for getting free edges (ones referenced by the only face) with help of analyzer ShapeAnalysis_Shell. Free edges are connected into wires only when they share the same vertex. If <splitclosed> is True extracts closed sub-wires out of built closed wires. If <splitopen> is True extracts closed sub-wires out of built open wires.

        """
        _ShapeAnalysis.ShapeAnalysis_FreeBounds_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_FreeBounds(*args))

    @staticmethod
    def DispatchWires(*args):
        r"""

        Parameters
        ----------
        wires: TopTools_HSequenceOfShape
        closed: TopoDS_Compound
        open: TopoDS_Compound

        Return
        -------
        None

        Description
        -----------
        Dispatches sequence of <wires> into two compounds <closed> for closed wires and <open> for open wires. If a compound is not empty wires are added into it.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_DispatchWires(*args)

    def GetClosedWires(self, *args):
        r"""
        Return
        -------
        TopoDS_Compound

        Description
        -----------
        Returns compound of closed wires out of free edges.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_GetClosedWires(self, *args)

    def GetOpenWires(self, *args):
        r"""
        Return
        -------
        TopoDS_Compound

        Description
        -----------
        Returns compound of open wires out of free edges.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_GetOpenWires(self, *args)

    @staticmethod
    def SplitWires(*args):
        r"""

        Parameters
        ----------
        wires: TopTools_HSequenceOfShape
        toler: float
        shared: bool
        closed: TopTools_HSequenceOfShape
        open: TopTools_HSequenceOfShape

        Return
        -------
        None

        Description
        -----------
        Extracts closed sub-wires out of <wires> and adds them to <closed>, open wires remained after extraction are put into <open>. If <shared> is True extraction is performed only when edges share the same vertex. If <shared> is False connection is performed only when ends of the edges are at distance less than <toler>.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_SplitWires(*args)

    @staticmethod
    def ConnectEdgesToWires(edges, toler, shared):
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_ConnectEdgesToWires(edges, toler, shared)

    @staticmethod
    def ConnectWiresToWires(iwires, toler, shared):
        return _ShapeAnalysis.ShapeAnalysis_FreeBounds_ConnectWiresToWires(iwires, toler, shared)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_FreeBounds

# Register ShapeAnalysis_FreeBounds in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_FreeBounds_swigregister(ShapeAnalysis_FreeBounds)
class ShapeAnalysis_FreeBoundsProperties(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        shape: TopoDS_Shape
        tolerance: float
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Creates the object and calls corresponding Init. <shape> should be a compound of faces.

        Parameters
        ----------
        shape: TopoDS_Shape
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Creates the object and calls corresponding Init. <shape> should be a compound of shells.

        """
        _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_FreeBoundsProperties(*args))

    def CheckContours(self, *args):
        r"""

        Parameters
        ----------
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_CheckContours(self, *args)

    def CheckNotches(self, *args):
        r"""

        Parameters
        ----------
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        fbData: ShapeAnalysis_FreeBoundData
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        freebound: TopoDS_Wire
        num: int
        notch: TopoDS_Wire
        prec: float (optional, default to 0.0)

        Return
        -------
        distMax: float

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_CheckNotches(self, *args)

    def ClosedFreeBound(self, *args):
        r"""

        Parameters
        ----------
        index: int

        Return
        -------
        opencascade::handle<ShapeAnalysis_FreeBoundData>

        Description
        -----------
        Returns properties of closed free bound specified by its rank number.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_ClosedFreeBound(self, *args)

    def ClosedFreeBounds(self, *args):
        r"""
        Return
        -------
        opencascade::handle<ShapeAnalysis_HSequenceOfFreeBounds>

        Description
        -----------
        Returns all closed free bounds.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_ClosedFreeBounds(self, *args)

    def DispatchBounds(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_DispatchBounds(self, *args)

    def FillProperties(self, *args):
        r"""

        Parameters
        ----------
        fbData: ShapeAnalysis_FreeBoundData
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_FillProperties(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        tolerance: float
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Initializes the object with given parameters. <shape> should be a compound of faces.

        Parameters
        ----------
        shape: TopoDS_Shape
        splitclosed: bool (optional, default to Standard_False)
        splitopen: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Initializes the object with given parameters. <shape> should be a compound of shells.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_Init(self, *args)

    def IsLoaded(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if shape is loaded.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_IsLoaded(self, *args)

    def NbClosedFreeBounds(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns number of closed free bounds.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_NbClosedFreeBounds(self, *args)

    def NbFreeBounds(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns number of free bounds.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_NbFreeBounds(self, *args)

    def NbOpenFreeBounds(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns number of open free bounds.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_NbOpenFreeBounds(self, *args)

    def OpenFreeBound(self, *args):
        r"""

        Parameters
        ----------
        index: int

        Return
        -------
        opencascade::handle<ShapeAnalysis_FreeBoundData>

        Description
        -----------
        Returns properties of open free bound specified by its rank number.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_OpenFreeBound(self, *args)

    def OpenFreeBounds(self, *args):
        r"""
        Return
        -------
        opencascade::handle<ShapeAnalysis_HSequenceOfFreeBounds>

        Description
        -----------
        Returns all open free bounds.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_OpenFreeBounds(self, *args)

    def Perform(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Builds and analyzes free bounds of the shape. First calls ShapeAnalysis_FreeBounds for building free bounds. Then on each free bound computes its properties: - area of the contour, - perimeter of the contour, - ratio of average length to average width of the contour, - average width of contour, - notches on the contour and for each notch - maximum width of the notch.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_Perform(self, *args)

    def Shape(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        Returns shape.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_Shape(self, *args)

    def Tolerance(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns tolerance.

        """
        return _ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_Tolerance(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_FreeBoundsProperties

# Register ShapeAnalysis_FreeBoundsProperties in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_FreeBoundsProperties_swigregister(ShapeAnalysis_FreeBoundsProperties)
class ShapeAnalysis_Geom(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def NearestPlane(*args):
        r"""

        Parameters
        ----------
        Pnts: TColgp_Array1OfPnt
        aPln: gp_Pln

        Return
        -------
        Dmax: float

        Description
        -----------
        Builds a plane out of a set of points in array Returns in <dmax> the maximal distance between the produced plane and given points.

        """
        return _ShapeAnalysis.ShapeAnalysis_Geom_NearestPlane(*args)

    @staticmethod
    def PositionTrsf(*args):
        r"""

        Parameters
        ----------
        coefs: TColStd_HArray2OfReal
        trsf: gp_Trsf
        unit: float
        prec: float

        Return
        -------
        bool

        Description
        -----------
        Builds transformation object out of matrix. Matrix must be 3 x 4. Unit is used as multiplier.

        """
        return _ShapeAnalysis.ShapeAnalysis_Geom_PositionTrsf(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeAnalysis.ShapeAnalysis_Geom_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Geom())
    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Geom

# Register ShapeAnalysis_Geom in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Geom_swigregister(ShapeAnalysis_Geom)
class ShapeAnalysis_ShapeContents(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Initialize fields and call ClearFlags().

        """
        _ShapeAnalysis.ShapeAnalysis_ShapeContents_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_ShapeContents(*args))

    def BigSplineSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_BigSplineSec(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clears all accumulated statistics.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_Clear(self, *args)

    def ClearFlags(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clears all flags.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_ClearFlags(self, *args)

    def IndirectSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_IndirectSec(self, *args)

    def GetModifyBigSplineMode(self):
        r"""GetModifyBigSplineMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyBigSplineMode(self)

    def SetModifyBigSplineMode(self, value):
        r"""SetModifyBigSplineMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyBigSplineMode(self, value)

    def GetModifyIndirectMode(self):
        r"""GetModifyIndirectMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyIndirectMode(self)

    def SetModifyIndirectMode(self, value):
        r"""SetModifyIndirectMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyIndirectMode(self, value)

    def GetModifyOffestSurfaceMode(self):
        r"""GetModifyOffestSurfaceMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyOffestSurfaceMode(self)

    def SetModifyOffestSurfaceMode(self, value):
        r"""SetModifyOffestSurfaceMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyOffestSurfaceMode(self, value)

    def GetModifyOffsetCurveMode(self):
        r"""GetModifyOffsetCurveMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyOffsetCurveMode(self)

    def SetModifyOffsetCurveMode(self, value):
        r"""SetModifyOffsetCurveMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyOffsetCurveMode(self, value)

    def GetModifyOffsetSurfaceMode(self):
        r"""GetModifyOffsetSurfaceMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyOffsetSurfaceMode(self)

    def SetModifyOffsetSurfaceMode(self, value):
        r"""SetModifyOffsetSurfaceMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyOffsetSurfaceMode(self, value)

    def GetModifyTrimmed2dMode(self):
        r"""GetModifyTrimmed2dMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyTrimmed2dMode(self)

    def SetModifyTrimmed2dMode(self, value):
        r"""SetModifyTrimmed2dMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyTrimmed2dMode(self, value)

    def GetModifyTrimmed3dMode(self):
        r"""GetModifyTrimmed3dMode(ShapeAnalysis_ShapeContents self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_GetModifyTrimmed3dMode(self)

    def SetModifyTrimmed3dMode(self, value):
        r"""SetModifyTrimmed3dMode(ShapeAnalysis_ShapeContents self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_SetModifyTrimmed3dMode(self, value)

    def NbBSplibeSurf(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbBSplibeSurf(self, *args)

    def NbBezierSurf(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbBezierSurf(self, *args)

    def NbBigSplines(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbBigSplines(self, *args)

    def NbC0Curves(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbC0Curves(self, *args)

    def NbC0Surfaces(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbC0Surfaces(self, *args)

    def NbEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbEdges(self, *args)

    def NbFaceWithSevWires(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbFaceWithSevWires(self, *args)

    def NbFaces(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbFaces(self, *args)

    def NbFreeEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbFreeEdges(self, *args)

    def NbFreeFaces(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbFreeFaces(self, *args)

    def NbFreeWires(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbFreeWires(self, *args)

    def NbIndirectSurf(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbIndirectSurf(self, *args)

    def NbNoPCurve(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbNoPCurve(self, *args)

    def NbOffsetCurves(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbOffsetCurves(self, *args)

    def NbOffsetSurf(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbOffsetSurf(self, *args)

    def NbSharedEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedEdges(self, *args)

    def NbSharedFaces(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedFaces(self, *args)

    def NbSharedFreeEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedFreeEdges(self, *args)

    def NbSharedFreeWires(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedFreeWires(self, *args)

    def NbSharedShells(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedShells(self, *args)

    def NbSharedSolids(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedSolids(self, *args)

    def NbSharedVertices(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedVertices(self, *args)

    def NbSharedWires(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSharedWires(self, *args)

    def NbShells(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbShells(self, *args)

    def NbSolids(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSolids(self, *args)

    def NbSolidsWithVoids(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbSolidsWithVoids(self, *args)

    def NbTrimSurf(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbTrimSurf(self, *args)

    def NbTrimmedCurve2d(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbTrimmedCurve2d(self, *args)

    def NbTrimmedCurve3d(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbTrimmedCurve3d(self, *args)

    def NbVertices(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbVertices(self, *args)

    def NbWireWithSevSeams(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbWireWithSevSeams(self, *args)

    def NbWireWitnSeam(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbWireWitnSeam(self, *args)

    def NbWires(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_NbWires(self, *args)

    def OffsetCurveSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_OffsetCurveSec(self, *args)

    def OffsetSurfaceSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_OffsetSurfaceSec(self, *args)

    def Perform(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        Counts quantities of sun-shapes in shape and stores sub-shapes according to flags.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_Perform(self, *args)

    def Trimmed2dSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_Trimmed2dSec(self, *args)

    def Trimmed3dSec(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeContents_Trimmed3dSec(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_ShapeContents

# Register ShapeAnalysis_ShapeContents in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_ShapeContents_swigregister(ShapeAnalysis_ShapeContents)
class ShapeAnalysis_ShapeTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        """
        _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_ShapeTolerance(*args))

    def AddTolerance(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        type: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        Adds data on new Shape to compute Cumulated Tolerance (prepares three computations: maximal, average, minimal).

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_AddTolerance(self, *args)

    def GlobalTolerance(self, *args):
        r"""

        Parameters
        ----------
        mode: int

        Return
        -------
        float

        Description
        -----------
        Returns the computed tolerance according to the <mode> <mode> = 0: average <mode> > 0: maximal <mode> < 0: minimal.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_GlobalTolerance(self, *args)

    def InTolerance(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        valmin: float
        valmax: float
        type: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        Determines which shapes have a tolerance within a given interval <type> is interpreted as in the method Tolerance.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_InTolerance(self, *args)

    def InitTolerance(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Initializes computation of cumulated tolerance.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_InitTolerance(self, *args)

    def OverTolerance(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        value: float
        type: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        Description
        -----------
        Determines which shapes have a tolerance over the given value <type> is interpreted as in the method Tolerance.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_OverTolerance(self, *args)

    def Tolerance(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        mode: int
        type: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        float

        Description
        -----------
        Determines a tolerance from the ones stored in a shape Remark: calls InitTolerance and AddTolerance, hence, can be used to start a series for cumulating tolerance <mode> = 0: returns the average value between sub-shapes, <mode> > 0: returns the maximal found, <mode> < 0: returns the minimal found. <type> defines what kinds of sub-shapes to consider: SHAPE (default): all: VERTEX, EDGE, FACE, VERTEX: only vertices, EDGE: only edges, FACE: only faces, SHELL: combined SHELL + FACE, for each face (and containing shell), also checks EDGE and VERTEX.

        """
        return _ShapeAnalysis.ShapeAnalysis_ShapeTolerance_Tolerance(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_ShapeTolerance

# Register ShapeAnalysis_ShapeTolerance in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_ShapeTolerance_swigregister(ShapeAnalysis_ShapeTolerance)
class ShapeAnalysis_Shell(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        """
        _ShapeAnalysis.ShapeAnalysis_Shell_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Shell(*args))

    def BadEdges(self, *args):
        r"""
        Return
        -------
        TopoDS_Compound

        Description
        -----------
        Returns the list of bad edges as a Compound It is empty (not null) if no edge are recorded as bad.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_BadEdges(self, *args)

    def CheckOrientedShells(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        alsofree: bool (optional, default to Standard_False)
        checkinternaledges: bool (optional, default to Standard_False)

        Return
        -------
        bool

        Description
        -----------
        Checks if shells fulfill orientation condition, i.e. if each edge is, either present once (free edge) or twice (connected edge) but with different orientations (FORWARD/REVERSED) Edges which do not fulfill these conditions are bad //! If <alsofree> is True free edges are considered. Free edges can be queried but are not bad.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_CheckOrientedShells(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clears data about loaded shells and performed checks.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_Clear(self, *args)

    def FreeEdges(self, *args):
        r"""
        Return
        -------
        TopoDS_Compound

        Description
        -----------
        Returns the list of free (not connected) edges as a Compound It is empty (not null) if no edge are recorded as free.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_FreeEdges(self, *args)

    def HasBadEdges(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Tells if at least one edge is recorded as bad.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_HasBadEdges(self, *args)

    def HasConnectedEdges(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Tells if at least one edge is connected (shared twice or more).

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_HasConnectedEdges(self, *args)

    def HasFreeEdges(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Tells if at least one edge is recorded as free (not connected).

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_HasFreeEdges(self, *args)

    def IsLoaded(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        Tells if a shape is loaded (only shells are checked).

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_IsLoaded(self, *args)

    def LoadShells(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        Adds shells contained in the <shape> to the list of loaded shells.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_LoadShells(self, *args)

    def Loaded(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        TopoDS_Shape

        Description
        -----------
        Returns a loaded shape specified by its rank number. Returns null shape if <num> is out of range.

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_Loaded(self, *args)

    def NbLoaded(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the actual number of loaded shapes (i.e. shells).

        """
        return _ShapeAnalysis.ShapeAnalysis_Shell_NbLoaded(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Shell

# Register ShapeAnalysis_Shell in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Shell_swigregister(ShapeAnalysis_Shell)
class ShapeAnalysis_Surface(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        S: Geom_Surface

        Return
        -------
        None

        Description
        -----------
        Creates an analyzer object on the basis of existing surface.

        """
        _ShapeAnalysis.ShapeAnalysis_Surface_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Surface(*args))

    def Adaptor3d(self, *args):
        r"""
        Return
        -------
        opencascade::handle<GeomAdaptor_Surface>

        Description
        -----------
        Returns the Adaptor. Creates it if not yet done.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Adaptor3d(self, *args)

    def Bounds(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        ufirst: float
        ulast: float
        vfirst: float
        vlast: float

        Description
        -----------
        Returns the bounds of the surface (from Bounds from Surface, but buffered).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Bounds(self, *args)

    def ComputeBoundIsos(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Computes bound isos (protected against exceptions).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_ComputeBoundIsos(self, *args)

    def DegeneratedValues(self, *args):
        r"""

        Parameters
        ----------
        P3d: gp_Pnt
        preci: float
        firstP2d: gp_Pnt2d
        lastP2d: gp_Pnt2d
        forward: bool (optional, default to Standard_True)

        Return
        -------
        firstpar: float
        lastpar: float

        Description
        -----------
        Returns True if there is at least one surface iso-line which is considered as degenerated with <preci> and distance between P3d and corresponding singular point is less than <preci> (like IsDegenerated). Returns characteristics of the first found boundary matching those criteria.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_DegeneratedValues(self, *args)

    def Gap(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns 3D distance found by one of the following methods. IsDegenerated, DegeneratedValues, ProjectDegenerated (distance between 3D point and found or last (if not found) singularity), IsUClosed, IsVClosed (minimum value of precision to consider the surface to be closed), ValueOfUV (distance between 3D point and found solution).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Gap(self, *args)

    def GetBoxUF(self, *args):
        r"""
        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_GetBoxUF(self, *args)

    def GetBoxUL(self, *args):
        r"""
        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_GetBoxUL(self, *args)

    def GetBoxVF(self, *args):
        r"""
        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_GetBoxVF(self, *args)

    def GetBoxVL(self, *args):
        r"""
        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_GetBoxVL(self, *args)

    def HasSingularities(self, *args):
        r"""

        Parameters
        ----------
        preci: float

        Return
        -------
        bool

        Description
        -----------
        Returns True if the surface has singularities for the given precision (i.e. if there are surface singularities with sizes not greater than precision).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_HasSingularities(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        S: Geom_Surface

        Return
        -------
        None

        Description
        -----------
        Loads existing surface.

        Parameters
        ----------
        other: ShapeAnalysis_Surface

        Return
        -------
        None

        Description
        -----------
        Reads all the data from another Surface, without recomputing.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Init(self, *args)

    def IsDegenerated(self, *args):
        r"""

        Parameters
        ----------
        P3d: gp_Pnt
        preci: float

        Return
        -------
        bool

        Description
        -----------
        Returns True if there is at least one surface boundary which is considered as degenerated with <preci> and distance between P3d and corresponding singular point is less than <preci>.

        Parameters
        ----------
        p2d1: gp_Pnt2d
        p2d2: gp_Pnt2d
        tol: float
        ratio: float

        Return
        -------
        bool

        Description
        -----------
        Returns True if straight pcurve going from point p2d1 to p2d2 is degenerate, i.e. lies in the singularity of the surface. NOTE: it uses another method of detecting singularity than used by ComputeSingularities() et al.! For that, maximums of distances between points p2d1, p2d2 and 0.5*(p2d1+p2d2) and between corresponding 3d points are computed. The pcurve (p2d1, p2d2) is considered as degenerate if: - max distance in 3d is less than <tol> - max distance in 2d is at least <ratio> times greater than the Resolution computed from max distance in 3d (max3d < tol && max2d > ratio * Resolution(max3d)) NOTE: <ratio> should be >1 (e.g. 10).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_IsDegenerated(self, *args)

    def IsUClosed(self, *args):
        r"""

        Parameters
        ----------
        preci: float (optional, default to -1)

        Return
        -------
        bool

        Description
        -----------
        Tells if the Surface is spatially closed in U with given precision. If <preci> < 0 then Precision::Confusion is used. If Geom_Surface says that the surface is U-closed, this method also says this. Otherwise additional analysis is performed, comparing given precision with the following distances: - periodic B-Splines are closed, - polynomial B-Spline with boundary multiplicities degree+1 and Bezier - maximum distance between poles, - rational B-Spline or one with boundary multiplicities not degree+1 - maximum distance computed at knots and their middles, - surface of extrusion - distance between ends of basis curve, - other (RectangularTrimmed and Offset) - maximum distance computed at 100 equi-distanted points.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_IsUClosed(self, *args)

    def IsVClosed(self, *args):
        r"""

        Parameters
        ----------
        preci: float (optional, default to -1)

        Return
        -------
        bool

        Description
        -----------
        Tells if the Surface is spatially closed in V with given precision. If <preci> < 0 then Precision::Confusion is used. If Geom_Surface says that the surface is V-closed, this method also says this. Otherwise additional analysis is performed, comparing given precision with the following distances: - periodic B-Splines are closed, - polynomial B-Spline with boundary multiplicities degree+1 and Bezier - maximum distance between poles, - rational B-Spline or one with boundary multiplicities not degree+1 - maximum distance computed at knots and their middles, - surface of revolution - distance between ends of basis curve, - other (RectangularTrimmed and Offset) - maximum distance computed at 100 equi-distanted points.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_IsVClosed(self, *args)

    def NbSingularities(self, *args):
        r"""

        Parameters
        ----------
        preci: float

        Return
        -------
        int

        Description
        -----------
        Returns the number of singularities for the given precision (i.e. number of surface singularities with sizes not greater than precision).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_NbSingularities(self, *args)

    def NextValueOfUV(self, *args):
        r"""

        Parameters
        ----------
        p2dPrev: gp_Pnt2d
        P3D: gp_Pnt
        preci: float
        maxpreci: float (optional, default to -1.0)

        Return
        -------
        gp_Pnt2d

        Description
        -----------
        Projects a point P3D on the surface. Does the same thing as ValueOfUV but tries to optimize computations by taking into account previous point <p2dPrev>: makes a step by UV and tries Newton algorithm. If <maxpreci> >0. and distance between solution and P3D is greater than <maxpreci>, that solution is considered as bad, and ValueOfUV() is used. If not succeeded, calls ValueOfUV().

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_NextValueOfUV(self, *args)

    def ProjectDegenerated(self, *args):
        r"""

        Parameters
        ----------
        P3d: gp_Pnt
        preci: float
        neighbour: gp_Pnt2d
        result: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        Projects a point <P3d> on a singularity by computing one of the coordinates of preliminary computed <result>. //! Finds the iso-line which is considered as degenerated with <preci> and a. distance between P3d and corresponding singular point is less than <preci> (like IsDegenerated) or b. difference between already computed <result>'s coordinate and iso-coordinate of the boundary is less than 2D resolution (computed from <preci> by Geom_Adaptor). Then sets not yet computed <result>'s coordinate taking it from <neighbour> and returns True.

        Parameters
        ----------
        nbrPnt: int
        points: TColgp_SequenceOfPnt
        pnt2d: TColgp_SequenceOfPnt2d
        preci: float
        direct: bool

        Return
        -------
        bool

        Description
        -----------
        Checks points at the beginning (direct is True) or end (direct is False) of array <points> to lie in singularity of surface, and if yes, adjusts the indeterminate 2d coordinate of these points by nearest point which is not in singularity. Returns True if some points were adjusted.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_ProjectDegenerated(self, *args)

    def SetDomain(self, *args):
        r"""

        Parameters
        ----------
        U1: float
        U2: float
        V1: float
        V2: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_SetDomain(self, *args)

    def Singularity(self, *args):
        r"""

        Parameters
        ----------
        num: int
        P3d: gp_Pnt
        firstP2d: gp_Pnt2d
        lastP2d: gp_Pnt2d

        Return
        -------
        preci: float
        firstpar: float
        lastpar: float
        uisodeg: bool

        Description
        -----------
        Returns the characteristics of the singularity specified by its rank number <num>. That means, that it is not necessary for <num> to be in the range [1, NbSingularities] but must be not greater than possible (see ComputeSingularities). The returned characteristics are: preci: the smallest precision with which the iso-line is considered as degenerated, P3d: 3D point of singularity (middle point of the surface iso-line), firstP2d and lastP2d: first and last 2D points of the iso-line in parametrical surface, firstpar and lastpar: first and last parameters of the iso-line in parametrical surface, uisodeg: if the degenerated iso-line is U-iso (True) or V-iso (False). Returns False if <num> is out of range, else returns True.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Singularity(self, *args)

    def Surface(self, *args):
        r"""
        Return
        -------
        opencascade::handle<Geom_Surface>

        Description
        -----------
        Returns a surface being analyzed.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Surface(self, *args)

    def TrueAdaptor3d(self, *args):
        r"""
        Return
        -------
        opencascade::handle<GeomAdaptor_Surface>

        Description
        -----------
        Returns the Adaptor (may be Null if method Adaptor() was not called).

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_TrueAdaptor3d(self, *args)

    def UCloseVal(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns minimum value to consider the surface as U-closed.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_UCloseVal(self, *args)

    def UIso(self, *args):
        r"""

        Parameters
        ----------
        U: float

        Return
        -------
        opencascade::handle<Geom_Curve>

        Description
        -----------
        Returns a U-Iso. Null if not possible or failed Remark: bound isos are buffered.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_UIso(self, *args)

    def UVFromIso(self, *args):
        r"""

        Parameters
        ----------
        P3D: gp_Pnt
        preci: float

        Return
        -------
        U: float
        V: float

        Description
        -----------
        Tries a refinement of an already computed couple (U,V) by using projecting 3D point on iso-lines: 1. boundaries of the surface, 2. iso-lines passing through (U,V) 3. iteratively received iso-lines passing through new U and new V (number of iterations is limited by 5 in each direction) Returns the best resulting distance between P3D and Value(U,V) in the case of success. Else, returns a very great value.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_UVFromIso(self, *args)

    def VCloseVal(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns minimum value to consider the surface as V-closed.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_VCloseVal(self, *args)

    def VIso(self, *args):
        r"""

        Parameters
        ----------
        V: float

        Return
        -------
        opencascade::handle<Geom_Curve>

        Description
        -----------
        Returns a V-Iso. Null if not possible or failed Remark: bound isos are buffered.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_VIso(self, *args)

    def Value(self, *args):
        r"""

        Parameters
        ----------
        u: float
        v: float

        Return
        -------
        gp_Pnt

        Description
        -----------
        Returns a 3D point specified by parameters in surface parametrical space.

        Parameters
        ----------
        p2d: gp_Pnt2d

        Return
        -------
        gp_Pnt

        Description
        -----------
        Returns a 3d point specified by a point in surface parametrical space.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_Value(self, *args)

    def ValueOfUV(self, *args):
        r"""

        Parameters
        ----------
        P3D: gp_Pnt
        preci: float

        Return
        -------
        gp_Pnt2d

        Description
        -----------
        Computes the parameters in the surface parametrical space of 3D point. The result is parameters of the point projected onto the surface. This method enhances functionality provided by the standard tool GeomAPI_ProjectPointOnSurface by treatment of cases when the projected point is near to the surface boundaries and when this standard tool fails.

        """
        return _ShapeAnalysis.ShapeAnalysis_Surface_ValueOfUV(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_Surface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Surface

# Register ShapeAnalysis_Surface in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Surface_swigregister(ShapeAnalysis_Surface)
class ShapeAnalysis_TransferParameters(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates empty tool with myShift = 0 and myScale = 1.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        Creates a tool and initializes it with edge and face.

        """
        _ShapeAnalysis.ShapeAnalysis_TransferParameters_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_TransferParameters(*args))

    def Init(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        Initialize a tool with edge and face.

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParameters_Init(self, *args)

    def IsSameRange(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if 3d curve of edge and pcurve are SameRange (in default implementation, if myScale == 1 and myShift == 0).

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParameters_IsSameRange(self, *args)

    def Perform(self, *args):
        r"""

        Parameters
        ----------
        Params: TColStd_HSequenceOfReal
        To2d: bool

        Return
        -------
        opencascade::handle<TColStd_HSequenceOfReal>

        Description
        -----------
        Transfers parameters given by sequence Params from 3d curve to pcurve (if To2d is True) or back (if To2d is False).

        Parameters
        ----------
        Param: float
        To2d: bool

        Return
        -------
        float

        Description
        -----------
        Transfers parameter given by sequence Params from 3d curve to pcurve (if To2d is True) or back (if To2d is False).

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParameters_Perform(self, *args)

    def SetMaxTolerance(self, *args):
        r"""

        Parameters
        ----------
        maxtol: float

        Return
        -------
        None

        Description
        -----------
        Sets maximal tolerance to use linear recomputation of parameters.

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParameters_SetMaxTolerance(self, *args)

    def TransferRange(self, *args):
        r"""

        Parameters
        ----------
        newEdge: TopoDS_Edge
        prevPar: float
        currPar: float
        To2d: bool

        Return
        -------
        None

        Description
        -----------
        Recomputes range of curves from NewEdge. If Is2d equals True parameters are recomputed by curve2d else by curve3d.

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParameters_TransferRange(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_TransferParameters_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_TransferParameters

# Register ShapeAnalysis_TransferParameters in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_TransferParameters_swigregister(ShapeAnalysis_TransferParameters)
class ShapeAnalysis_Wire(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        wire: TopoDS_Wire
        face: TopoDS_Face
        precision: float

        Return
        -------
        None

        Description
        -----------
        Creates object with standard TopoDS_Wire, face and precision.

        Parameters
        ----------
        sbwd: ShapeExtend_WireData
        face: TopoDS_Face
        precision: float

        Return
        -------
        None

        Description
        -----------
        Creates the object with WireData object, face and precision.

        """
        _ShapeAnalysis.ShapeAnalysis_Wire_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_Wire(*args))

    def CheckClosed(self, *args):
        r"""

        Parameters
        ----------
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if wire is closed, performs CheckConnected, CheckDegenerated and CheckLacking for the first and the last edges Returns: True if at least one check returned True Status: FAIL1 or DONE1: see CheckConnected FAIL2 or DONE2: see CheckDegenerated.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckClosed(self, *args)

    def CheckConnected(self, *args):
        r"""

        Parameters
        ----------
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Calls to CheckConnected for each edge Returns: True if at least one pair of disconnected edges (not sharing the same vertex) was detected.

        Parameters
        ----------
        num: int
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Checks connected edges (num-th and preceding). Tests with starting preci from <SBWD> or with <prec> if it is greater. Considers Vertices. Returns: False if edges are connected by the common vertex, else True Status: OK: Vertices (end of num-1 th edge and start on num-th one) are already the same DONE1: Absolutely confused (gp::Resolution) DONE2: Confused at starting <preci> from <SBWD> DONE3: Confused at <prec> but not <preci> FAIL1: Not confused FAIL2: Not confused but confused with <preci> if reverse num-th edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckConnected(self, *args)

    def CheckCurveGap(self, *args):
        r"""

        Parameters
        ----------
        num: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks gap between points on 3D curve and points on surface generated by pcurve of the num-th edge. The distance can be queried by MinDistance3d. //! Returns: True if status is DONE Status: OK: Gap is less than myPrecision DONE: Gap is greater than myPrecision FAIL: No 3d curve(s) on the edge(s).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckCurveGap(self, *args)

    def CheckCurveGaps(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckCurveGaps(self, *args)

    def CheckDegenerated(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Calls to CheckDegenerated for each edge Returns: True if at least one incorrect degenerated edge was detected.

        Parameters
        ----------
        num: int
        dgnr1: gp_Pnt2d
        dgnr2: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        Checks for degenerated edge between two adjacent ones. Fills parameters dgnr1 and dgnr2 with points in parametric space that correspond to the singularity (either gap that needs to be filled by degenerated edge or that already filled) Returns: False if no singularity or edge is already degenerated, otherwise True Status: OK: No surface singularity, or edge is already degenerated DONE1: Degenerated edge should be inserted (gap in 2D) DONE2: Edge <num> should be made degenerated (recompute pcurve and set the flag) FAIL1: One of edges neighbouring to degenerated one has no pcurve FAIL2: Edge marked as degenerated and has no pcurve but singularity is not detected.

        Parameters
        ----------
        num: int

        Return
        -------
        bool

        Description
        -----------
        Checks for degenerated edge between two adjacent ones. Remark: Calls previous function Status: See the function above for details.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckDegenerated(self, *args)

    def CheckEdgeCurves(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Checks edges geometry (consistency of 2d and 3d senses, adjasment of curves to the vertices, etc.). The order of the checks: Call ShapeAnalysis_Wire to check: ShapeAnalysis_Edge::CheckCurve3dWithPCurve (1), ShapeAnalysis_Edge::CheckVertcesWithPCurve (2), ShapeAnalysis_Edge::CheckVertcesWithCurve3d (3), CheckSeam   (4) Additional: CheckGap3d  (5), CheckGap2d  (6), ShapeAnalysis_Edge::CheckSameParameter (7) Returns: True if at least one check returned True Remark: The numbers in brackets show with what DONEi or FAILi the status can be queried.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckEdgeCurves(self, *args)

    def CheckGap2d(self, *args):
        r"""

        Parameters
        ----------
        num: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks gap between edges in 2D (pcurves). Checks the distance between ends of pcurves of the num-th and preceding edge. The distance can be queried by MinDistance2d. //! Returns: True if status is DONE Status: OK: Gap is less than parametric precision out of myPrecision DONE: Gap is greater than parametric precision out of myPrecision FAIL: No pcurve(s) on the edge(s).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckGap2d(self, *args)

    def CheckGap3d(self, *args):
        r"""

        Parameters
        ----------
        num: int (optional, default to 0)

        Return
        -------
        bool

        Description
        -----------
        Checks gap between edges in 3D (3d curves). Checks the distance between ends of 3d curves of the num-th and preceding edge. The distance can be queried by MinDistance3d. //! Returns: True if status is DONE Status: OK: Gap is less than myPrecision DONE: Gap is greater than myPrecision FAIL: No 3d curve(s) on the edge(s).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckGap3d(self, *args)

    def CheckGaps2d(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckGaps2d(self, *args)

    def CheckGaps3d(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckGaps3d(self, *args)

    def CheckIntersectingEdges(self, *args):
        r"""

        Parameters
        ----------
        num: int
        points2d: IntRes2d_SequenceOfIntersectionPoint
        points3d: TColgp_SequenceOfPnt
        errors: TColStd_SequenceOfReal

        Return
        -------
        bool

        Description
        -----------
        Checks two adjacent edges for intersecting. Intersection is reported only if intersection point is not enclosed by the common end vertex of the edges. Returns: True if intersection is found. If returns True it also fills the sequences of intersection points, corresponding 3d points, and errors for them (half-distances between intersection points in 3d calculated from one and from another edge) Status: FAIL1: No pcurve FAIL2: No vertices DONE1: Self-intersection found.

        Parameters
        ----------
        num: int

        Return
        -------
        bool

        Description
        -----------
        Checks two adjacent edges for intersecting. Remark: Calls the previous method Status: See the function above for details.

        Parameters
        ----------
        num1: int
        num2: int
        points2d: IntRes2d_SequenceOfIntersectionPoint
        points3d: TColgp_SequenceOfPnt
        errors: TColStd_SequenceOfReal

        Return
        -------
        bool

        Description
        -----------
        Checks i-th and j-th edges for intersecting. Remark: See the previous method for details.

        Parameters
        ----------
        num1: int
        num2: int

        Return
        -------
        bool

        Description
        -----------
        Checks i-th and j-th edges for intersecting. Remark: Calls previous method. Status: See the function above for details.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckIntersectingEdges(self, *args)

    def CheckLacking(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Calls to CheckLacking for each edge Returns: True if at least one lacking edge was detected.

        Parameters
        ----------
        num: int
        Tolerance: float
        p2d1: gp_Pnt2d
        p2d2: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        Checks if there is a gap in 2d between edges, not comprised by the tolerance of their common vertex. If <Tolerance> is greater than 0. and less than tolerance of the vertex, then this value is used for check. Returns: True if not closed gap was detected p2d1 and p2d2 are the endpoint of <num-1>th edge and start of the <num>th edge in 2d. Status: OK: No edge is lacking (3d and 2d connection) FAIL1: edges have no vertices (at least one of them) FAIL2: edges are neither connected by common vertex, nor have coincided vertices FAIL1: edges have no pcurves DONE1: the gap is detected which cannot be closed by the tolerance of the common vertex (or with value of <Tolerance>) DONE2: is set (together with DONE1) if gap is detected and the vector (p2d2 - p2d1) goes in direction opposite to the pcurves of the edges (if angle is more than 0.9*PI).

        Parameters
        ----------
        num: int
        Tolerance: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if there is a gap in 2D between edges and not comprised by vertex tolerance The value of SBWD.thepreci is used. Returns: False if no edge should be inserted Status: OK: No edge is lacking (3d and 2d connection) DONE1: The vertex tolerance should be increased only (2d gap is small) DONE2: Edge can be inserted (3d and 2d gaps are large enough).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckLacking(self, *args)

    def CheckLoop(self, *args):
        r"""

        Parameters
        ----------
        aMapLoopVertices: TopTools_IndexedMapOfShape
        aMapVertexEdges: TopTools_DataMapOfShapeListOfShape
        aMapSmallEdges: TopTools_MapOfShape
        aMapSeemEdges: TopTools_MapOfShape

        Return
        -------
        bool

        Description
        -----------
        Checks existence of loop on wire and return vertices which are loop vertices (vertices belonging to a few pairs of edges).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckLoop(self, *args)

    def CheckNotchedEdges(self, *args):
        r"""

        Parameters
        ----------
        num: int
        Tolerance: float (optional, default to 0.0)

        Return
        -------
        shortNum: int
        param: float

        Description
        -----------
        Detects a notch.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckNotchedEdges(self, *args)

    def CheckOrder(self, *args):
        r"""

        Parameters
        ----------
        isClosed: bool (optional, default to Standard_True)
        mode3d: bool (optional, default to Standard_True)

        Return
        -------
        bool

        Description
        -----------
        Calls CheckOrder and returns False if wire is already ordered (tail-to-head), True otherwise Flag <isClosed> defines if the wire is closed or not Flag <mode3d> defines which mode is used (3d or 2d).

        Parameters
        ----------
        sawo: ShapeAnalysis_WireOrder
        isClosed: bool (optional, default to Standard_True)
        theMode3D: bool (optional, default to Standard_True)
        theModeBoth: bool (optional, default to Standard_False)

        Return
        -------
        bool

        Description
        -----------
        Analyzes the order of the edges in the wire, uses class WireOrder for that purpose. Flag <isClosed> defines if the wire is closed or not Flag <theMode3D> defines 3D or 2d mode. Flag <theModeBoth> defines miscible mode and the flag <theMode3D> is ignored. Returns False if wire is already ordered (tail-to-head), True otherwise. Use returned WireOrder object for deeper analysis. Status: OK: the same edges orientation, the same edges sequence DONE1: the same edges orientation, not the same edges sequence DONE2: as DONE1 and gaps more than myPrecision DONE3: not the same edges orientation (some need to be reversed) DONE4: as DONE3 and gaps more than myPrecision FAIL: algorithm failed (could not detect order).

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckOrder(self, *args)

    def CheckOuterBound(self, *args):
        r"""

        Parameters
        ----------
        APIMake: bool (optional, default to Standard_True)

        Return
        -------
        bool

        Description
        -----------
        Checks if wire defines an outer bound on the face Uses ShapeAnalysis::IsOuterBound for analysis If <APIMake> is True uses BRepAPI_MakeWire to build the wire, if False (to be used only when edges share common vertices) uses BRep_Builder to build the wire.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckOuterBound(self, *args)

    def CheckSeam(self, *args):
        r"""

        Parameters
        ----------
        num: int
        C1: Geom2d_Curve
        C2: Geom2d_Curve

        Return
        -------
        cf: float
        cl: float

        Description
        -----------
        Checks if a seam pcurves are correct oriented Returns: False (status OK) if given edge is not a seam or if it is OK C1 - current pcurve for FORWARD edge, C2 - current pcurve for REVERSED edge (if returns True they should be swapped for the seam), cf, cl - first and last parameters on curves Status: OK: Pcurves are correct or edge is not seam DONE: Seam pcurves should be swapped.

        Parameters
        ----------
        num: int

        Return
        -------
        bool

        Description
        -----------
        Checks if a seam pcurves are correct oriented See previous functions for details.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckSeam(self, *args)

    def CheckSelfIntersectingEdge(self, *args):
        r"""

        Parameters
        ----------
        num: int
        points2d: IntRes2d_SequenceOfIntersectionPoint
        points3d: TColgp_SequenceOfPnt

        Return
        -------
        bool

        Description
        -----------
        Checks if num-th edge is self-intersecting. Self-intersection is reported only if intersection point lies outside of both end vertices of the edge. Returns: True if edge is self-intersecting. If returns True it also fills the sequences of intersection points and corresponding 3d points (only that are not enclosed by a vertices) Status: FAIL1: No pcurve FAIL2: No vertices DONE1: Self-intersection found.

        Parameters
        ----------
        num: int

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckSelfIntersectingEdge(self, *args)

    def CheckSelfIntersection(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Checks self-intersection of the wire (considering pcurves) Looks for self-intersecting edges and each pair of intersecting edges. Warning: It does not check each edge with any other one (only each two adjacent edges) The order of the checks: CheckSelfIntersectingEdge, CheckIntersectingEdges Returns: True if at least one check returned True Status: FAIL1 or DONE1 - see CheckSelfIntersectingEdge FAIL2 or DONE2 - see CheckIntersectingEdges.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckSelfIntersection(self, *args)

    def CheckShapeConnect(self, *args):
        r"""

        Parameters
        ----------
        shape: TopoDS_Shape
        prec: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Checks with what orientation <shape> (wire or edge) can be connected to the wire. Tests distances with starting <preci> from <SBWD> (close confusion), but if given <prec> is greater, tests with <prec> (coarse confusion). The smallest found distance can be returned by MinDistance3d //! Returns: False if status is FAIL (see below) Status: DONE1: If <shape> follows <SBWD>, direct sense (normal) DONE2: If <shape> follows <SBWD>, but if reversed DONE3: If <shape> precedes <SBWD>, direct sense DONE4: If <shape> precedes <SBWD>, but if reversed FAIL1: If <shape> is neither an edge nor a wire FAIL2: If <shape> cannot be connected to <SBWD> //! DONE5: To the tail of <SBWD> the <shape> is closer with direct sense DONE6: To the head of <SBWD> the <shape> is closer with direct sense //! Remark: Statuses DONE1 - DONE4, FAIL1 - FAIL2 are basic and describe the nearest connection of the <shape> to <SBWD>. Statuses DONE5 and DONE6 are advanced and are to be used when analyzing with what sense (direct or reversed) the <shape> should be connected to <SBWD>: For tail of <SBWD> if DONE4 is True <shape> should be direct, otherwise reversed. For head of <SBWD> if DONE5 is True <shape> should be direct, otherwise reversed.

        Parameters
        ----------
        shape: TopoDS_Shape
        prec: float (optional, default to 0.0)

        Return
        -------
        tailhead: float
        tailtail: float
        headtail: float
        headhead: float

        Description
        -----------
        The same as previous CheckShapeConnect but is more advanced. It returns the distances between each end of <sbwd> and each end of <shape>. For example, <tailhead> stores distance between tail of <sbwd> and head of <shape> Remark: First method CheckShapeConnect calls this one.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckShapeConnect(self, *args)

    def CheckSmall(self, *args):
        r"""

        Parameters
        ----------
        precsmall: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Calls to CheckSmall for each edge Returns: True if at least one small edge was detected.

        Parameters
        ----------
        num: int
        precsmall: float (optional, default to 0.0)

        Return
        -------
        bool

        Description
        -----------
        Checks if an edge has a length not greater than myPreci or precsmall (if it is smaller) Returns: False if its length is greater than precision Status: OK: edge is not small or degenerated DONE1: edge is small, vertices are the same DONE2: edge is small, vertices are not the same FAIL: no 3d curve and pcurve.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckSmall(self, *args)

    def CheckSmallArea(self, *args):
        r"""

        Parameters
        ----------
        theWire: TopoDS_Wire

        Return
        -------
        bool

        Description
        -----------
        Checks if wire has parametric area less than precision.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckSmallArea(self, *args)

    def CheckTail(self, *args):
        r"""

        Parameters
        ----------
        theEdge1: TopoDS_Edge
        theEdge2: TopoDS_Edge
        theMaxSine: float
        theMaxWidth: float
        theMaxTolerance: float
        theEdge11: TopoDS_Edge
        theEdge12: TopoDS_Edge
        theEdge21: TopoDS_Edge
        theEdge22: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_CheckTail(self, *args)

    def ClearStatuses(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Unsets all the status and distance fields wire, face and precision are not cleared.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_ClearStatuses(self, *args)

    def Face(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        Returns the working face.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Face(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        wire: TopoDS_Wire
        face: TopoDS_Face
        precision: float

        Return
        -------
        None

        Description
        -----------
        Initializes the object with standard TopoDS_Wire, face and precision.

        Parameters
        ----------
        sbwd: ShapeExtend_WireData
        face: TopoDS_Face
        precision: float

        Return
        -------
        None

        Description
        -----------
        Initializes the object with WireData object, face and precision.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Init(self, *args)

    def IsLoaded(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if wire is loaded and has number of edges >0.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_IsLoaded(self, *args)

    def IsReady(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if IsLoaded and underlying face is not null.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_IsReady(self, *args)

    def LastCheckStatus(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        Querying the status of the LAST performed 'Advanced' checking procedure.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_LastCheckStatus(self, *args)

    def Load(self, *args):
        r"""

        Parameters
        ----------
        wire: TopoDS_Wire

        Return
        -------
        None

        Description
        -----------
        Loads the object with standard TopoDS_Wire.

        Parameters
        ----------
        sbwd: ShapeExtend_WireData

        Return
        -------
        None

        Description
        -----------
        Loads the object with WireData object.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Load(self, *args)

    def MaxDistance2d(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the last maximal distance in 2D-UV computed by CheckContinuity2d.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_MaxDistance2d(self, *args)

    def MaxDistance3d(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the last maximal distance in 3D computed by CheckOrientation, CheckConnected, CheckContinuity3d, CheckVertex, CheckNewVertex, CheckSameParameter.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_MaxDistance3d(self, *args)

    def MinDistance2d(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the last lowest distance in 2D-UV computed by CheckContinuity2d.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_MinDistance2d(self, *args)

    def MinDistance3d(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the last lowest distance in 3D computed by CheckOrientation, CheckConnected, CheckContinuity3d, CheckVertex, CheckNewVertex.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_MinDistance3d(self, *args)

    def NbEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the number of edges in the wire, or 0 if it is not loaded.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_NbEdges(self, *args)

    def Perform(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Performs all the checks in the following order: CheckOrder, CheckSmall, CheckConnected, CheckEdgeCurves, CheckDegenerated, CheckSelfIntersection, CheckLacking, CheckClosed Returns: True if at least one method returned True; For deeper analysis use Status...(status) methods.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Perform(self, *args)

    def Precision(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the value of precision.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Precision(self, *args)

    def SetFace(self, *args):
        r"""

        Parameters
        ----------
        face: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        Loads the face the wire lies on.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_SetFace(self, *args)

    def SetPrecision(self, *args):
        r"""

        Parameters
        ----------
        precision: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_SetPrecision(self, *args)

    def SetSurface(self, *args):
        r"""

        Parameters
        ----------
        surface: Geom_Surface

        Return
        -------
        None

        Description
        -----------
        Loads the surface the wire lies on.

        Parameters
        ----------
        surface: Geom_Surface
        location: TopLoc_Location

        Return
        -------
        None

        Description
        -----------
        Loads the surface the wire lies on.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_SetSurface(self, *args)

    def StatusClosed(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusClosed(self, *args)

    def StatusConnected(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusConnected(self, *args)

    def StatusCurveGaps(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusCurveGaps(self, *args)

    def StatusDegenerated(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusDegenerated(self, *args)

    def StatusEdgeCurves(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusEdgeCurves(self, *args)

    def StatusGaps2d(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusGaps2d(self, *args)

    def StatusGaps3d(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusGaps3d(self, *args)

    def StatusLacking(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusLacking(self, *args)

    def StatusLoop(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusLoop(self, *args)

    def StatusOrder(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusOrder(self, *args)

    def StatusSelfIntersection(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusSelfIntersection(self, *args)

    def StatusSmall(self, *args):
        r"""

        Parameters
        ----------
        Status: ShapeExtend_Status

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_StatusSmall(self, *args)

    def Surface(self, *args):
        r"""
        Return
        -------
        opencascade::handle<ShapeAnalysis_Surface>

        Description
        -----------
        Returns the working surface.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_Surface(self, *args)

    def WireData(self, *args):
        r"""
        Return
        -------
        opencascade::handle<ShapeExtend_WireData>

        Description
        -----------
        Returns wire object being analyzed.

        """
        return _ShapeAnalysis.ShapeAnalysis_Wire_WireData(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_Wire_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_Wire

# Register ShapeAnalysis_Wire in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_Wire_swigregister(ShapeAnalysis_Wire)
class ShapeAnalysis_WireOrder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        Parameters
        ----------
        theMode3D: bool
        theTolerance: float
        theModeBoth: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Creates a WireOrder. Flag <theMode3D> defines 3D or 2d mode. Flag <theModeBoth> defines miscible mode and the flag <theMode3D> is ignored. Warning: Parameter <theTolerance> is not used in algorithm.

        """
        _ShapeAnalysis.ShapeAnalysis_WireOrder_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_WireOrder(*args))

    def Add(self, *args):
        r"""

        Parameters
        ----------
        theStart3d: gp_XYZ
        theEnd3d: gp_XYZ

        Return
        -------
        None

        Description
        -----------
        Adds a couple of points 3D (start, end).

        Parameters
        ----------
        theStart2d: gp_XY
        theEnd2d: gp_XY

        Return
        -------
        None

        Description
        -----------
        Adds a couple of points 2D (start, end).

        Parameters
        ----------
        theStart3d: gp_XYZ
        theEnd3d: gp_XYZ
        theStart2d: gp_XY
        theEnd2d: gp_XY

        Return
        -------
        None

        Description
        -----------
        Adds a couple of points 3D and 2D (start, end).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Add(self, *args)

    def Chain(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        n1: int
        n2: int

        Description
        -----------
        Returns, for the chain n0 num, starting and ending numbers of edges. In the list of ordered edges (see Ordered for originals).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Chain(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Clears the list of edges, but not mode and tol.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Clear(self, *args)

    def Couple(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        n1: int
        n2: int

        Description
        -----------
        Returns, for the couple n0 num, the two implied edges In the list of ordered edges.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Couple(self, *args)

    def Gap(self, *args):
        r"""

        Parameters
        ----------
        num: int (optional, default to 0)

        Return
        -------
        float

        Description
        -----------
        Returns the gap between a couple and its preceding <num> is considered ordered If <num> = 0 (D), returns the greatest gap found.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Gap(self, *args)

    def IsDone(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Tells if Perform has been done Else, the following methods returns original values.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_IsDone(self, *args)

    def GetKeepLoopsMode(self):
        r"""GetKeepLoopsMode(ShapeAnalysis_WireOrder self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_GetKeepLoopsMode(self)

    def SetKeepLoopsMode(self, value):
        r"""SetKeepLoopsMode(ShapeAnalysis_WireOrder self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_SetKeepLoopsMode(self, value)

    def NbChains(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the count of computed chains.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_NbChains(self, *args)

    def NbCouples(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the count of computed couples.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_NbCouples(self, *args)

    def NbEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the count of added couples of points (one per edges).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_NbEdges(self, *args)

    def Ordered(self, *args):
        r"""

        Parameters
        ----------
        theIdx: int

        Return
        -------
        int

        Description
        -----------
        Returns the number of original edge which correspond to the newly ordered number <n> Warning: the returned value is NEGATIVE if edge should be reversed.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Ordered(self, *args)

    def Perform(self, *args):
        r"""

        Parameters
        ----------
        closed: bool (optional, default to Standard_True)

        Return
        -------
        None

        Description
        -----------
        Computes the better order Optimised if the couples were already in order The criterium is: two couples in order if distance between end-prec and start-cur is less then starting tolerance <tol> Else, the smallest distance is reached Warning: Parameter <closed> not used.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Perform(self, *args)

    def SetChains(self, *args):
        r"""

        Parameters
        ----------
        gap: float

        Return
        -------
        None

        Description
        -----------
        Determines the chains inside which successive edges have a gap less than a given value. Queried by NbChains and Chain.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_SetChains(self, *args)

    def SetCouples(self, *args):
        r"""

        Parameters
        ----------
        gap: float

        Return
        -------
        None

        Description
        -----------
        Determines the couples of edges for which end and start fit inside a given gap. Queried by NbCouples and Couple Warning: function isn't implemented.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_SetCouples(self, *args)

    def SetMode(self, *args):
        r"""

        Parameters
        ----------
        theMode3D: bool
        theTolerance: float
        theModeBoth: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Sets new values. Clears the edge list if the mode (<theMode3D> or <theModeBoth> ) changes. Clears the connexion list. Warning: Parameter <theTolerance> is not used in algorithm.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_SetMode(self, *args)

    def Status(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the status of the order (0 if not done): 0: all edges are direct and in sequence 1: all edges are direct but some are not in sequence -1: some edges are reversed, but no gap remain 3: edges in sequence are just shifted in forward or reverse manner.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Status(self, *args)

    def Tolerance(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns the working tolerance.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_Tolerance(self, *args)

    def XY(self, *args):
        r"""

        Parameters
        ----------
        theIdx: int
        theStart2D: gp_XY
        theEnd2D: gp_XY

        Return
        -------
        None

        Description
        -----------
        Returns the values of the couple <num>, as 2D values.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_XY(self, *args)

    def XYZ(self, *args):
        r"""

        Parameters
        ----------
        theIdx: int
        theStart3D: gp_XYZ
        theEnd3D: gp_XYZ

        Return
        -------
        None

        Description
        -----------
        Returns the values of the couple <num>, as 3D values.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireOrder_XYZ(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_WireOrder

# Register ShapeAnalysis_WireOrder in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_WireOrder_swigregister(ShapeAnalysis_WireOrder)
class ShapeAnalysis_WireVertex(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Empty constructor.

        """
        _ShapeAnalysis.ShapeAnalysis_WireVertex_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_WireVertex(*args))

    def Analyze(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Analyze(self, *args)

    def Data(self, *args):
        r"""

        Parameters
        ----------
        num: int
        pos: gp_XYZ

        Return
        -------
        upre: float
        ufol: float

        Description
        -----------
        Returns the recorded status for a vertex With its recorded position and parameters on both edges These values are relevant regarding the status: Status Meaning Position Preceding Following 0 Same no no no 1 SameCoord no no no 2 Close no no no 3 End yes no yes 4 Start yes yes no 5 Inters yes yes yes -1 Disjoined no no no.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Data(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        wire: TopoDS_Wire
        preci: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        swbd: ShapeExtend_WireData
        preci: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Init(self, *args)

    def IsDone(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns True if analysis was performed, else returns False.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_IsDone(self, *args)

    def Load(self, *args):
        r"""

        Parameters
        ----------
        wire: TopoDS_Wire

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        sbwd: ShapeExtend_WireData

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Load(self, *args)

    def NbEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the number of edges in analyzed wire (i.e. the length of all arrays).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_NbEdges(self, *args)

    def NextCriter(self, *args):
        r"""

        Parameters
        ----------
        crit: int
        num: int (optional, default to 0)

        Return
        -------
        int

        Description
        -----------
        For a given criter, returns the rank of the vertex which follows <num> and has the same status. 0 if no more Acts as an iterator, starts on the first one Criters are: 0: same vertex (status 0) 1: a solution exists (status >= 0) 2: same coords (i.e. same params) (status 0 1 2) 3: same coods but not same vertex (status 1 2) 4: redefined coords (status 3 4 5) -1: no solution (status -1).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_NextCriter(self, *args)

    def NextStatus(self, *args):
        r"""

        Parameters
        ----------
        stat: int
        num: int (optional, default to 0)

        Return
        -------
        int

        Description
        -----------
        For a given status, returns the rank of the vertex which follows <num> and has the same status. 0 if no more Acts as an iterator, starts on the first one.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_NextStatus(self, *args)

    def Position(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        gp_XYZ

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Position(self, *args)

    def Precision(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        Returns precision value used in analysis.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Precision(self, *args)

    def SetClose(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        None

        Description
        -----------
        Records status 'Close Coords' (at the Precision of <self>).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetClose(self, *args)

    def SetDisjoined(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        None

        Description
        -----------
        <num> cannot be said as same vertex.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetDisjoined(self, *args)

    def SetEnd(self, *args):
        r"""

        Parameters
        ----------
        num: int
        pos: gp_XYZ
        ufol: float

        Return
        -------
        None

        Description
        -----------
        <num> is the End of preceding Edge, and its projection on the following one lies on it at the Precision of <self> <ufol> gives the parameter on the following edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetEnd(self, *args)

    def SetInters(self, *args):
        r"""

        Parameters
        ----------
        num: int
        pos: gp_XYZ
        upre: float
        ufol: float

        Return
        -------
        None

        Description
        -----------
        <num> is the Intersection of both Edges <upre> is the parameter on preceding edge, <ufol> on following edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetInters(self, *args)

    def SetPrecision(self, *args):
        r"""

        Parameters
        ----------
        preci: float

        Return
        -------
        None

        Description
        -----------
        Sets the precision for work Analysing: for each Vertex, comparison between the end of the preceding edge and the start of the following edge Each Vertex rank corresponds to the End Vertex of the Edge of same rank, in the ShapeExtend_WireData. I.E. for Vertex <num>, Edge <num> is the preceding one, <num+1> is the following one.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetPrecision(self, *args)

    def SetSameCoords(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        None

        Description
        -----------
        Records status 'Same Coords' (at the Vertices Tolerances).

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetSameCoords(self, *args)

    def SetSameVertex(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        None

        Description
        -----------
        Records status 'Same Vertex' (logically) on Vertex <num>.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetSameVertex(self, *args)

    def SetStart(self, *args):
        r"""

        Parameters
        ----------
        num: int
        pos: gp_XYZ
        upre: float

        Return
        -------
        None

        Description
        -----------
        <num> is the Start of following Edge, its projection on the preceding one lies on it at the Precision of <self> <upre> gives the parameter on the preceding edge.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_SetStart(self, *args)

    def Status(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        int

        Description
        -----------
        Returns the recorded status for a vertex More detail by method Data.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_Status(self, *args)

    def UFollowing(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_UFollowing(self, *args)

    def UPrevious(self, *args):
        r"""

        Parameters
        ----------
        num: int

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_UPrevious(self, *args)

    def WireData(self, *args):
        r"""
        Return
        -------
        opencascade::handle<ShapeExtend_WireData>

        Description
        -----------
        Returns analyzed wire.

        """
        return _ShapeAnalysis.ShapeAnalysis_WireVertex_WireData(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_WireVertex

# Register ShapeAnalysis_WireVertex in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_WireVertex_swigregister(ShapeAnalysis_WireVertex)
class ShapeAnalysis_TransferParametersProj(ShapeAnalysis_TransferParameters):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates empty constructor.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _ShapeAnalysis.ShapeAnalysis_TransferParametersProj_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_TransferParametersProj(*args))

    @staticmethod
    def CopyNMVertex(*args):
        r"""

        Parameters
        ----------
        theVert: TopoDS_Vertex
        toedge: TopoDS_Edge
        fromedge: TopoDS_Edge

        Return
        -------
        TopoDS_Vertex

        Description
        -----------
        Make a copy of non-manifold vertex theVert (i.e. create new TVertex and replace PointRepresentations for this vertex from fromedge to toedge. Other representations were copied).

        Parameters
        ----------
        theVert: TopoDS_Vertex
        toFace: TopoDS_Face
        fromFace: TopoDS_Face

        Return
        -------
        TopoDS_Vertex

        Description
        -----------
        Make a copy of non-manifold vertex theVert (i.e. create new TVertex and replace PointRepresentations for this vertex from fromFace to toFace. Other representations were copied).

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParametersProj_CopyNMVertex(*args)

    def GetForceProjection(self):
        r"""GetForceProjection(ShapeAnalysis_TransferParametersProj self) -> Standard_Boolean"""
        return _ShapeAnalysis.ShapeAnalysis_TransferParametersProj_GetForceProjection(self)

    def SetForceProjection(self, value):
        r"""SetForceProjection(ShapeAnalysis_TransferParametersProj self, Standard_Boolean value)"""
        return _ShapeAnalysis.ShapeAnalysis_TransferParametersProj_SetForceProjection(self, value)

    def Perform(self, *args):
        r"""

        Parameters
        ----------
        Papams: TColStd_HSequenceOfReal
        To2d: bool

        Return
        -------
        opencascade::handle<TColStd_HSequenceOfReal>

        Description
        -----------
        Transfers parameters given by sequence Params from 3d curve to pcurve (if To2d is True) or back (if To2d is False).

        Parameters
        ----------
        Param: float
        To2d: bool

        Return
        -------
        float

        Description
        -----------
        Transfers parameter given by Param from 3d curve to pcurve (if To2d is True) or back (if To2d is False).

        """
        return _ShapeAnalysis.ShapeAnalysis_TransferParametersProj_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_TransferParametersProj_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_TransferParametersProj

# Register ShapeAnalysis_TransferParametersProj in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_TransferParametersProj_swigregister(ShapeAnalysis_TransferParametersProj)

@classnotwrapped
class ShapeAnalysis_BoxBndTreeSelector:
	pass

@classnotwrapped
class ShapeCustom_ConvertToRevolution:
	pass


class ShapeAnalysis_HSequenceOfFreeBounds(ShapeAnalysis_SequenceOfFreeBounds, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ShapeAnalysis.ShapeAnalysis_HSequenceOfFreeBounds_swiginit(self, _ShapeAnalysis.new_ShapeAnalysis_HSequenceOfFreeBounds(*args))

    def Sequence(self):
        return _ShapeAnalysis.ShapeAnalysis_HSequenceOfFreeBounds_Sequence(self)

    def Append(self, *args):
        return _ShapeAnalysis.ShapeAnalysis_HSequenceOfFreeBounds_Append(self, *args)

    def ChangeSequence(self):
        return _ShapeAnalysis.ShapeAnalysis_HSequenceOfFreeBounds_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeAnalysis_HSequenceOfFreeBounds_DownCast(t)

    __swig_destroy__ = _ShapeAnalysis.delete_ShapeAnalysis_HSequenceOfFreeBounds

# Register ShapeAnalysis_HSequenceOfFreeBounds in _ShapeAnalysis:
_ShapeAnalysis.ShapeAnalysis_HSequenceOfFreeBounds_swigregister(ShapeAnalysis_HSequenceOfFreeBounds)



@deprecated
def shapeanalysis_AdjustByPeriod(*args):
	return shapeanalysis.AdjustByPeriod(*args)

@deprecated
def shapeanalysis_AdjustToPeriod(*args):
	return shapeanalysis.AdjustToPeriod(*args)

@deprecated
def shapeanalysis_ContourArea(*args):
	return shapeanalysis.ContourArea(*args)

@deprecated
def shapeanalysis_FindBounds(*args):
	return shapeanalysis.FindBounds(*args)

@deprecated
def shapeanalysis_GetFaceUVBounds(*args):
	return shapeanalysis.GetFaceUVBounds(*args)

@deprecated
def shapeanalysis_IsOuterBound(*args):
	return shapeanalysis.IsOuterBound(*args)

@deprecated
def shapeanalysis_OuterWire(*args):
	return shapeanalysis.OuterWire(*args)

@deprecated
def shapeanalysis_TotCross2D(*args):
	return shapeanalysis.TotCross2D(*args)

@deprecated
def ShapeAnalysis_Curve_GetSamplePoints(*args):
	return ShapeAnalysis_Curve.GetSamplePoints(*args)

@deprecated
def ShapeAnalysis_Curve_GetSamplePoints(*args):
	return ShapeAnalysis_Curve.GetSamplePoints(*args)

@deprecated
def ShapeAnalysis_Curve_IsClosed(*args):
	return ShapeAnalysis_Curve.IsClosed(*args)

@deprecated
def ShapeAnalysis_Curve_IsPeriodic(*args):
	return ShapeAnalysis_Curve.IsPeriodic(*args)

@deprecated
def ShapeAnalysis_Curve_IsPeriodic(*args):
	return ShapeAnalysis_Curve.IsPeriodic(*args)

@deprecated
def ShapeAnalysis_Curve_IsPlanar(*args):
	return ShapeAnalysis_Curve.IsPlanar(*args)

@deprecated
def ShapeAnalysis_Curve_IsPlanar(*args):
	return ShapeAnalysis_Curve.IsPlanar(*args)

@deprecated
def ShapeAnalysis_FreeBounds_DispatchWires(*args):
	return ShapeAnalysis_FreeBounds.DispatchWires(*args)

@deprecated
def ShapeAnalysis_FreeBounds_SplitWires(*args):
	return ShapeAnalysis_FreeBounds.SplitWires(*args)

@deprecated
def ShapeAnalysis_Geom_NearestPlane(*args):
	return ShapeAnalysis_Geom.NearestPlane(*args)

@deprecated
def ShapeAnalysis_Geom_PositionTrsf(*args):
	return ShapeAnalysis_Geom.PositionTrsf(*args)

@deprecated
def ShapeAnalysis_TransferParametersProj_CopyNMVertex(*args):
	return ShapeAnalysis_TransferParametersProj.CopyNMVertex(*args)

@deprecated
def ShapeAnalysis_TransferParametersProj_CopyNMVertex(*args):
	return ShapeAnalysis_TransferParametersProj.CopyNMVertex(*args)



